#include	"ver.h"

#define	STR_SQUARE	"ۡࡦ"

#define	STR_EQUIP_WIELDING	""
#define	STR_EQUIP_SHIELD	""
#define	STR_EQUIP_BOW	""
#define	STR_EQUIP_ARW	""
#define	STR_EQUIP_HEAD	"Ƭ"
#define	STR_EQUIP_NECK	""
#define	STR_EQUIP_BODY	""
#define	STR_EQUIP_ARM	""
#define	STR_EQUIP_RIGHT_HAND	""
#define	STR_EQUIP_LEFT_HAND	""
#define	STR_EQUIP_FEET	"­"
#define	STR_EQUIP_ABOUT_BODY	"ޥ"
#define	STR_EQUIP_LIGHT_SOURCE	""

#define	STR_DISARM	""
#define	STR_GOLD	"GOLD"

#define	STR_FIG	"Ʈǽ"
#define	STR_MON	"Ʈǽ"
#define	STR_HUN	"ͷ⵻ǽ"
#define	STR_THI	"յǽ"

#define	STR_MAG	"ˡ"
#define	STR_SOR	"Ʈˡ"
#define	STR_ENC	"ٱˡ"
#define	STR_SUM	"ˡ"
#define	STR_PRI	""
#define	STR_SHA	""
#define	STR_BAR	""
#define	STR_NIN	"Ǧ"

	{ N_MSG_NULL,
		"" },
	{ N_MSG_NOT_NULL,
		" " },

	{ N_MSG_S,
		"%s" },

	{ N_MSG_GAME_NAME,
		STR_FILE_NAME_GAME },

	{ N_MSG_CANCEL,
		"󥻥뤷ޤ" },
	{ N_MSG_HIT_ANY_KEY,
		"- 򲡤Ʋ -" },
	{ N_MSG_HIT_ENTER_KEY,
		"- [ENTER] 򲡤Ʋ -" },

	{ N_MSG_H_LINE,
		"-" },
	{ N_MSG_V_LINE,
		"|" },
	{ N_MSG_CROSS,
		"+" },
	{ N_MSG_H_FRAME,
		"----------------------------------------"
		"+---------------------------------------" },
	{ N_MSG_STAT_FRAME,
		"----------------------------------------" },

	{ N_MSG_SQUARE,
		STR_SQUARE },

	{ N_MSG_MORE,
		"-more-" },
	{ N_MSG_MORE_CLEAR,
		"      " },

	{ N_MSG_WAIT_KEY,
		"[ENTER] 򲡤Ʋ" },

	{ N_MSG_INCOMPLETE,
		",ޤƤޤ" },

	{ N_MSG_GAME_OVER,
		"ѡƥǤޤ"
		"[CTRL]+[Q] 򲡤ƽλƲ" },

	{ N_MSG_CHILD_PS,
		"%s ƤӽФޤ\n" },

	{ N_MSG_OUT_MAP_FILE_1,
		"ޥåפϤե̾ϤƲ" },
	{ N_MSG_OUT_MAP_FILE_2,
		"ǥե '%s'" },
	{ N_MSG_OUT_MAP_FILE_3,
		"ϥե̾ '%s'" },
	{ N_MSG_OUT_MAP_FILE_ASK_OK,
		"Ϥޤ?" },

	{ N_MSG_MAIN_RACE_HUMAN,
		"ҥ塼ޥ" },
	{ N_MSG_MAIN_RACE_HALF_ELF,
		"ϡա" },
	{ N_MSG_MAIN_RACE_ELF,
		"" },
	{ N_MSG_MAIN_RACE_DWARF,
		"ɥ" },
	{ N_MSG_MAIN_RACE_VIVID,
		"ӥӥå" },

	{ N_MSG_SUB_RACE_NULL,
		"̵" },
	{ N_MSG_SUB_RACE_CAT,
		"ǭ" },
	{ N_MSG_SUB_RACE_DOG,
		"" },
	{ N_MSG_SUB_RACE_MOUSE,
		"ͥ" },
	{ N_MSG_SUB_RACE_RABBIT,
		"" },
	{ N_MSG_SUB_RACE_MONKEY,
		"" },
	{ N_MSG_SUB_RACE_PIG,
		"" },
	{ N_MSG_SUB_RACE_BIRD,
		"Ļ" },
	{ N_MSG_SUB_RACE_LIZARD,
		"" },

	{ N_MSG_RACE_NAME_VEGE,
		"" },

	{ N_MSG_MALE,
		"" },
	{ N_MSG_FEMALE,
		"" },

	{ N_MSG_EQUIP_WIELDING,
		STR_EQUIP_WIELDING },
	{ N_MSG_EQUIP_SHIELD,
		STR_EQUIP_SHIELD },
	{ N_MSG_EQUIP_BOW,
		STR_EQUIP_BOW },
	{ N_MSG_EQUIP_ARW,
		STR_EQUIP_ARW },
	{ N_MSG_EQUIP_HEAD,
		STR_EQUIP_HEAD },
	{ N_MSG_EQUIP_NECK,
		STR_EQUIP_NECK },
	{ N_MSG_EQUIP_BODY,
		STR_EQUIP_BODY },
	{ N_MSG_EQUIP_ARM,
		STR_EQUIP_ARM },
	{ N_MSG_EQUIP_RIGHT_HAND,
		STR_EQUIP_RIGHT_HAND },
	{ N_MSG_EQUIP_LEFT_HAND,
		STR_EQUIP_LEFT_HAND },
	{ N_MSG_EQUIP_FEET,
		STR_EQUIP_FEET },
	{ N_MSG_EQUIP_ABOUT_BODY,
		STR_EQUIP_ABOUT_BODY },
	{ N_MSG_EQUIP_LIGHT_SOURCE,
		STR_EQUIP_LIGHT_SOURCE },

	{ N_MSG_STAT_DEAD,
		"˴" },
	{ N_MSG_STAT_STONE,
		"в" },
	{ N_MSG_STAT_PARALYZE,
		"" },
	{ N_MSG_STAT_POISON,
		"" },
	{ N_MSG_STAT_CONFUSION,
		"" },
	{ N_MSG_STAT_BLIND,
		"" },
	{ N_MSG_STAT_SLEEP,
		"̲" },
	{ N_MSG_STAT_SILENCE,
		"" },
	{ N_MSG_STAT_FEAR,
		"" },
	{ N_MSG_STAT_HALLUCINATION,
		"" },
	{ N_MSG_STAT_CHARM,
		"̥λ" },
	{ N_MSG_STAT_FLY,
		"ͷ" },
	{ N_MSG_STAT_HUNGRY,
		"ʢ" },
	{ N_MSG_STAT_STARVATION,
		"" },
	{ N_MSG_STAT_FAINT,
		"ޤ" },
	{ N_MSG_STAT_DRUNK,
		"줤" },

	{ N_MSG_ABL_NAME_HP,
		"HP" },
	{ N_MSG_ABL_NAME_MP,
		"MP" },
	{ N_MSG_ABL_NAME_DEX,
		"DEX" },
	{ N_MSG_ABL_NAME_STR,
		"STR" },
	{ N_MSG_ABL_NAME_AGI,
		"AGI" },
	{ N_MSG_ABL_NAME_WIS,
		"WIS" },
	{ N_MSG_ABL_NAME_INT,
		"INT" },
	{ N_MSG_ABL_NAME_CHA,
		"CHA" },
	{ N_MSG_ABL_NAME_FIG,
		"FIG" },
	{ N_MSG_ABL_NAME_MON,
		"MON" },
	{ N_MSG_ABL_NAME_HUN,
		"HUN" },
	{ N_MSG_ABL_NAME_THI,
		"THI" },
	{ N_MSG_ABL_NAME_MAG,
		"MAG" },
	{ N_MSG_ABL_NAME_SOR,
		"SOR" },
	{ N_MSG_ABL_NAME_ENC,
		"ENC" },
	{ N_MSG_ABL_NAME_SUM,
		"SUM" },
	{ N_MSG_ABL_NAME_PRI,
		"PRI" },
	{ N_MSG_ABL_NAME_SHA,
		"SHA" },
	{ N_MSG_ABL_NAME_BAR,
		"BAR" },
	{ N_MSG_ABL_NAME_NIN,
		"NIN" },

	{ N_MSG_CLASS_FIGHTER,
		"" },
	{ N_MSG_CLASS_MONK,
		"Ʈ" },
	{ N_MSG_CLASS_HUNTER,
		"" },
	{ N_MSG_CLASS_THIEF,
		"±" },
	{ N_MSG_CLASS_PRIEST,
		"η" },
	{ N_MSG_CLASS_SHAMAN,
		"Ȥ" },
	{ N_MSG_CLASS_BARD,
		"ͷ" },
	{ N_MSG_CLASS_WIZARD,
		"ѻ" },
	{ N_MSG_CLASS_SUMMONER,
		"" },
	{ N_MSG_CLASS_BISHOP,
		"" },

	{ N_MSG_MBR_DIE,
		"*** %s ϻ ***" },

	{ N_MSG_EXP_PARTY,
		"ƥС %ld ηиͤ" },
	{ N_MSG_EXP_MBR,
		"%s  %ld ηиͤ" },
	{ N_MSG_LEV_UP,
		"*** %s  %s Υ٥뤬 %ld ˤʤä ***" },

	{ N_MSG_STAT_DUN_LEV_TTL_FLOOR,
		"Ͼ  : " },
	{ N_MSG_STAT_DUN_LEV_TTL_BASE,
		"ϲ  : " },
	{ N_MSG_STAT_DUN_LEV_TTL_0,
		"Į    : " },

	{ N_MSG_NAME_BAR,
		"" },
	{ N_MSG_NAME_INN,
		"ɲ" },
	{ N_MSG_NAME_TEMPLE,
		"" },
	{ N_MSG_NAME_WPN,
		"ﲰ" },
	{ N_MSG_NAME_ARMOR,
		"ɶ" },
	{ N_MSG_NAME_MAGIC,
		"ˡŹ" },
	{ N_MSG_NAME_GROCERY,
		"߲" },
	{ N_MSG_NAME_RESTAURANT,
		"쥹ȥ" },
	{ N_MSG_NAME_TEAROOM,
		"ƥ롼" },
	{ N_MSG_NAME_TOBACCO,
		"Х" },

	{ N_MSG_AUTO_RELOAD,
		"%s  %s ưŶޤ" },

	{ N_MSG_ATTACK_PUNCH,
		"%s  %s 򲥤ä" },
	{ N_MSG_ATTACK_KICK,
		"%s  %s 򽳤ä" },
	{ N_MSG_ATTACK_BITE,
		"%s  %s ˳ߤĤ" },
	{ N_MSG_ATTACK_KNOCK,
		"%s  %s áĤ" },
	{ N_MSG_ATTACK_STING,
		"%s  %s ͤ" },
	{ N_MSG_ATTACK_SLASH,
		"%s  %s ڤĤ" },
	{ N_MSG_ATTACK_MOW,
		"%s  %s ʧä" },
	{ N_MSG_ATTACK_SHOOT,
		"%s  %s ͤä" },
	{ N_MSG_ATTACK_THROW,
		"%s  %s ꤲĤ" },
	{ N_MSG_ATTACK_ERR,
		"Ʈå顼" },
	{ N_MSG_FIGHT_CRTCL_STD,
		"%s Υƥ롦ҥå" },
	{ N_MSG_FIGHT_HIT_STD,
		"%s  %s  %d Υ᡼Ϳ" },
	{ N_MSG_FIGHT_MISS_STD,
		"%s ι⤬ %s 򳰤" },
	{ N_MSG_FIGHT_KILL_STD,
		"++XX %s  %s ݤ XX++" },

	{ N_MSG_SPELL,
		"%s  %s μʸ򾧤" },

	{ N_MSG_TRGT_POS,
		"ֻ" },

	{ N_MSG_ACT_NULL,
		"" },
	{ N_MSG_ACT_MNSTR_FIGHT,
		"臘" },
	{ N_MSG_ACT_MNSTR_THROW,
		"ꤲ" },
	{ N_MSG_ACT_MNSTR_TAIL,
		"ɤ" },
	{ N_MSG_ACT_MBR_FIGHT,
		"С臘" },
	{ N_MSG_ACT_MBR_THROW,
		"Сꤲ" },
	{ N_MSG_ACT_MBR_TAIL,
		"Сɤ" },
	{ N_MSG_ACT_DOOR_OPEN,
		"ɥ򳫤" },
	{ N_MSG_ACT_DOOR_CLOSE,
		"ɥĤ" },
	{ N_MSG_ACT_DOOR_JAM,
		"ɥꤹ" },
	{ N_MSG_ACT_DOOR_DISARM,
		"ɥθ" STR_DISARM },
	{ N_MSG_ACT_DOOR_BREAK,
		"ɥ" },
	{ N_MSG_ACT_DOOR_PEEP,
		"Τ" },
	{ N_MSG_ACT_DOOR_SRCH,
		"ɥĴ٤" },
	{ N_MSG_ACT_TRAP_DISARM,
		"櫤" STR_DISARM },
	{ N_MSG_ACT_TRAP_BREAK,
		"櫤" },
	{ N_MSG_ACT_TRAP_SRCH,
		"櫤Ĵ٤" },
	{ N_MSG_ACT_ITEM_PICK_UP,
		"ƥҤ" },
	{ N_MSG_ACT_ITEM_OPEN,
		"ƥ򳫤" },
	{ N_MSG_ACT_ITEM_DISARM,
		"ƥ" STR_DISARM "" },
	{ N_MSG_ACT_ITEM_BREAK,
		"ƥ" },
	{ N_MSG_ACT_ITEM_SRCH,
		"ƥĴ٤" },
	{ N_MSG_ACT_ITEM_SEND,
		"ƥϤ" },
	{ N_MSG_ACT_ITEM_DROP,
		"ƥȤ" },
	{ N_MSG_ACT_ITEM_RECEIVE,
		"ƥ餦" },
	{ N_MSG_ACT_POTION_QUAFF,
		"" },
	{ N_MSG_ACT_POTION_FILL,
		"󥿥" },
	{ N_MSG_ACT_SCROLL_READ,
		"ʪɤ" },
	{ N_MSG_ACT_STICK_ZAP,
		"Ȥ" },
	{ N_MSG_ACT_FOOD_EAT,
		"ʪ򿩤٤" },
	{ N_MSG_ACT_TOBACCO_SMOKE,
		"Х" },
	{ N_MSG_ACT_EQUIP,
		"" },
	{ N_MSG_ACT_TAKE_OFF,
		"򳰤" },
	{ N_MSG_ACT_EQUIP_MBR,
		"" },
	{ N_MSG_ACT_TAKE_OFF_MBR,
		"򳰤" },
	{ N_MSG_ACT_SRCH,
		"Ĵ٤" },

/* ƥ */
	{ N_MSG_ITEM_UNKNOWN,
		"Υƥ" },

	{ N_MSG_ITEM_MJR_NAME_WEAPON,
		"" },
	{ N_MSG_ITEM_MJR_NAME_ARMOR,
		"" },
	{ N_MSG_ITEM_MJR_NAME_POTION,
		"" },
	{ N_MSG_ITEM_MJR_NAME_SCROLL,
		"ʪ" },
	{ N_MSG_ITEM_MJR_NAME_STICK,
		"" },
	{ N_MSG_ITEM_MJR_NAME_ACCESSORY,
		"" },
	{ N_MSG_ITEM_MJR_NAME_FOOD,
		"" },
	{ N_MSG_ITEM_MJR_NAME_CHEST,
		"Ȣ" },
	{ N_MSG_ITEM_MJR_NAME_COIN,
		"" },
	{ N_MSG_ITEM_MJR_NAME_GEM,
		"" },
	{ N_MSG_ITEM_MJR_NAME_MISC,
		"¾Υƥ" },
	{ N_MSG_ITEM_MJR_NAME_ERR,
		"Υƥ" },

	{ N_MSG_ITEM_MNR_NAME_SWORD,
		"" },
	{ N_MSG_ITEM_MNR_NAME_BOW,
		"" },
	{ N_MSG_ITEM_MNR_NAME_ARW,
		"" },
	{ N_MSG_ITEM_MNR_NAME_STONE,
		"" },
	{ N_MSG_ITEM_MNR_NAME_DAGGER,
		"" },
	{ N_MSG_ITEM_MNR_NAME_ARMOR_HEAD,
		"" },
	{ N_MSG_ITEM_MNR_NAME_ARMOR_BODY,
		"" },
	{ N_MSG_ITEM_MNR_NAME_ARMOR_ABOUT_BODY,
		"ޥ" },
	{ N_MSG_ITEM_MNR_NAME_ARMOR_ARM,
		"" },
	{ N_MSG_ITEM_MNR_NAME_ARMOR_SHIELD,
		"" },
	{ N_MSG_ITEM_MNR_NAME_ARMOR_FEET,
		"֡" },
	{ N_MSG_ITEM_MNR_NAME_POTION,
		"" },
	{ N_MSG_ITEM_MNR_NAME_SCROLL,
		"ʪ" },
	{ N_MSG_ITEM_MNR_NAME_WAND,
		"" },
	{ N_MSG_ITEM_MNR_NAME_ROD,
		"å" },
	{ N_MSG_ITEM_MNR_NAME_STAFF,
		"å" },
	{ N_MSG_ITEM_MNR_NAME_RING,
		"" },
	{ N_MSG_ITEM_MNR_NAME_AMULET,
		"" },
	{ N_MSG_ITEM_MNR_NAME_NECKLACE,
		"ͥå쥹" },
	{ N_MSG_ITEM_MNR_NAME_FOOD,
		"" },
	{ N_MSG_ITEM_MNR_NAME_CHEST,
		"Ȣ" },
	{ N_MSG_ITEM_MNR_NAME_COIN,
		"" },
	{ N_MSG_ITEM_MNR_NAME_GEM,
		"" },
	{ N_MSG_ITEM_MNR_NAME_LIGHT,
		"" },
	{ N_MSG_ITEM_MNR_NAME_SPIKE,
		"ţ" },
	{ N_MSG_ITEM_MNR_NAME_TOBACCO,
		"Х" },
	{ N_MSG_ITEM_MNR_NAME_PIPE,
		"ѥ" },
	{ N_MSG_ITEM_MNR_NAME_JUNK,
		"߶" },
	{ N_MSG_ITEM_MNR_NAME_ERR,
		"Υƥ" },

/* Check Item Data */

	{ N_MSG_CHK_ITEM_DATA_NAME,
		"%s Ĵ٤" },
	{ N_MSG_CHK_ITEM_DATA_KIND,
		" %s " },
	{ N_MSG_CHK_ITEM_DATA_CAN_USE_MON,
		"" STR_MON "(MON)臘" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_MON,
		"" STR_MON "(MON)¤" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_THI,
		"" STR_THI "(THI)¤" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_MAG,
		"" STR_MAG "(MAG)¤" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_SOR,
		"" STR_SOR "(SOR)¤" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_ENC,
		"" STR_ENC "(ENC)¤" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_PRI,
		"" STR_PRI "(PRI)¤" },
	{ N_MSG_CHK_ITEM_DATA_CAN_NOT_USE_SHA,
		"" STR_SHA "(SHA)¤" },

/*  */

	{ N_MSG_WPN_KNIFE,
		"ʥ" },
	{ N_MSG_WPN_KRIS_KNIFE,
		"ꥹʥ" },
	{ N_MSG_WPN_MAIN_GAUCHE,
		"ޥᥴ" },
	{ N_MSG_WPN_SWORD_BREAKER,
		"ɡ֥졼" },
	{ N_MSG_WPN_KATAR,
		"" },
	{ N_MSG_WPN_JAMADHAR,
		"ޥϥ" },
	{ N_MSG_WPN_KUKRI,
		"" },

	{ N_MSG_WPN_SHORT_SWORD,
		"硼ȡ" },
	{ N_MSG_WPN_GLADIUS,
		"ǥ" },

	{ N_MSG_WPN_LONG_SWORD,
		"󥰡" },
	{ N_MSG_WPN_BROAD_SWORD,
		"֥ɡ" },
	{ N_MSG_WPN_CLAYMORE,
		"쥤⥢" },
	{ N_MSG_WPN_BASTARD_SWORD,
		"Хɡ" },
	{ N_MSG_WPN_GREAT_SWORD,
		"졼ȡ" },

	{ N_MSG_WPN_SABRE,
		"٥" },
	{ N_MSG_WPN_SHAMSHIR,
		"ॷ" },
	{ N_MSG_WPN_TALWAR,
		"" },
	{ N_MSG_WPN_FALCHION,
		"ե륷" },
	{ N_MSG_WPN_CUTLASS,
		"åȥ饹" },
	{ N_MSG_WPN_SHOTEL,
		"ƥ" },
	{ N_MSG_WPN_KATANA,
		"" },

	{ N_MSG_WPN_RAPIER,
		"쥤ԥ" },
	{ N_MSG_WPN_ESTOC,
		"ȥå" },

	{ N_MSG_WPN_HAND_AXE,
		"ϥɡå" },
	{ N_MSG_WPN_FRANCISCA,
		"ե󥭥" },
	{ N_MSG_WPN_BHUJ,
		"֡" },

	{ N_MSG_WPN_BATTLE_AXE,
		"Хȥ롦å" },
	{ N_MSG_WPN_BROAD_AXE,
		"֥ɡå" },
	{ N_MSG_WPN_GREAT_AXE,
		"졼ȡå" },

	{ N_MSG_WPN_SPEAR,
		"ԥ" },
	{ N_MSG_WPN_PILUM,
		"ԥ" },
	{ N_MSG_WPN_PIKE,
		"ѥ" },
	{ N_MSG_WPN_JAVELIN,
		"٥" },
	{ N_MSG_WPN_TRIDENT,
		"ȥ饤ǥ" },

	{ N_MSG_WPN_LANCE,
		"" },

	{ N_MSG_WPN_WOODEN_CLUB,
		"" },
	{ N_MSG_WPN_QUARTER_STAFF,
		"" },
	{ N_MSG_WPN_LIGHT_FLAIL,
		"饤ȡե쥤" },
	{ N_MSG_WPN_HEAVY_FLAIL,
		"إӡե쥤" },
	{ N_MSG_WPN_MORNINGSTAR,
		"⡼˥󥰡" },

	{ N_MSG_WPN_LIGHT_MACE,
		"饤ȡᥤ" },
	{ N_MSG_WPN_HEAVY_MACE,
		"إӡᥤ" },

	{ N_MSG_WPN_WAR_HAMMER,
		"ϥޡ" },
	{ N_MSG_WPN_WAR_PICK,
		"ԥå" },
	{ N_MSG_WPN_ZAGHNOL,
		"ʥ" },
	{ N_MSG_WPN_BEC_DE_CORBIN,
		"٥ɡХ" },

	{ N_MSG_WPN_PARTIZAN,
		"ѥ" },
	{ N_MSG_WPN_POLEAXE,
		"ݡ롦å" },
	{ N_MSG_WPN_GLAIVE,
		"쥤" },
	{ N_MSG_WPN_HALBERD,
		"ϥ٥" },
	{ N_MSG_WPN_CHAUVE_SOURIS,
		"" },
	{ N_MSG_WPN_CORSESCA,
		"륻" },
	{ N_MSG_WPN_SCYTHE,
		"" },
	{ N_MSG_WPN_FAUCHARD,
		"ե㡼" },
	{ N_MSG_WPN_GUISARME,
		"" },

	{ N_MSG_WPN_BRASS_KNUCKLE,
		"֥饹ʥå" },
	{ N_MSG_WPN_BAGH_NAKH,
		"Хʥ" },

	{ N_MSG_WPN_SLING,
		"" },
	{ N_MSG_WPN_SHORT_BOW,
		"硼ȡܥ" },
	{ N_MSG_WPN_LONG_BOW,
		"󥰡ܥ" },
	{ N_MSG_WPN_COMPOSITE_BOW,
		"ݥåȡܥ" },
	{ N_MSG_WPN_LIGHT_CROSS_BOW,
		"饤ȡܥ" },
	{ N_MSG_WPN_HEAVY_CROSS_BOW,
		"إӡܥ" },
	{ N_MSG_WPN_BLOW_GUN,
		"᤭" },

	{ N_MSG_WPN_STONE,
		"" },
	{ N_MSG_WPN_BULLET,
		"󥰤" },
	{ N_MSG_WPN_ARW,
		"" },
	{ N_MSG_WPN_BOLT,
		"ܥ" },
	{ N_MSG_WPN_NEEDLE,
		"᤭" },

	{ N_MSG_WPN_DAGGER,
		"" },
	{ N_MSG_WPN_DARTS,
		"" },
	{ N_MSG_WPN_SHURIKEN,
		"΢" },
	{ N_MSG_WPN_BOOMERANG,
		"֡" },

/* ɶ */

	{ N_MSG_ARMOR_LEATHER_CAP,
		"쥶å" },
	{ N_MSG_ARMOR_METAL_CAP,
		"᥿롦å" },
	{ N_MSG_ARMOR_SALLET,
		"å" },
	{ N_MSG_ARMOR_CLOSE_HELMET,
		"إ" },
	{ N_MSG_ARMOR_SILVER_CROWN,
		"С饦" },
	{ N_MSG_ARMOR_GOLDEN_CROWN,
		"ǥ󡦥饦" },
	{ N_MSG_ARMOR_JEWELED_CROWN,
		"奨ɡ饦" },

	{ N_MSG_ARMOR_ROBE,
		"" },
	{ N_MSG_ARMOR_SOFT_LEATHER_ARMOR,
		"եȡ쥶" },
	{ N_MSG_ARMOR_HARD_LEATHER_ARMOR,
		"ϡɡ쥶" },
	{ N_MSG_ARMOR_RING_MAIL,
		"󥰡ᥤ" },
	{ N_MSG_ARMOR_SCALE_MAIL,
		"롦ᥤ" },
	{ N_MSG_ARMOR_DRAGON_SCALE,
		"ɥ饴󡦥" },
	{ N_MSG_ARMOR_LAMELLAR_ARMOR,
		"顼" },
	{ N_MSG_ARMOR_CHAIN_MAIL,
		"󡦥ᥤ" },
	{ N_MSG_ARMOR_MITHRIL_CHAIN,
		"ߥ롦" },
	{ N_MSG_ARMOR_PLATE_ARMOR,
		"ץ졼ȡ" },

	{ N_MSG_ARMOR_CLOAK,
		"" },

	{ N_MSG_ARMOR_LEATHER_GLOVES,
		"쥶" },
	{ N_MSG_ARMOR_GAUNTLETS,
		"ȥå" },

	{ N_MSG_ARMOR_LEATHER_BOOTS,
		"쥶֡" },
	{ N_MSG_ARMOR_GREAVE,
		"꡼" },

	{ N_MSG_ARMOR_BUCKLER_SHIELD,
		"Хå顼" },
	{ N_MSG_ARMOR_ROUND_SHIELD,
		"饦ɡ" },
	{ N_MSG_ARMOR_KITE_SHIELD,
		"ȡ" },
	{ N_MSG_ARMOR_HEATER_SHIELD,
		"ҡ" },

/* Potion */

	{ N_MSG_POTION_WATER,
		"" },
	{ N_MSG_POTION_MILK,
		"ߥ륯" },
	{ N_MSG_POTION_WHITE_WINE,
		"磻" },
	{ N_MSG_POTION_RED_WINE,
		"֥磻" },
	{ N_MSG_POTION_ROSE_WINE,
		"磻" },
	{ N_MSG_POTION_ALE,
		"" },
	{ N_MSG_POTION_BRANDY,
		"֥ǡ" },
	{ N_MSG_POTION_RUM,
		"" },
	{ N_MSG_POTION_COFFE,
		"ҡ" },
	{ N_MSG_POTION_ICE_COFFE,
		"ҡ" },
	{ N_MSG_POTION_TEA,
		"ȥ졼ȡƥ" },
	{ N_MSG_POTION_MILK_TEA,
		"ߥ륯ƥ" },
	{ N_MSG_POTION_LEMON_TEA,
		"󡦥ƥ" },
	{ N_MSG_POTION_ICE_TEA,
		"ƥ" },
	{ N_MSG_POTION_ICE_MILK_TEA,
		"ߥ륯ƥ" },
	{ N_MSG_POTION_ICE_LEMON_TEA,
		"󡦥ƥ" },
	{ N_MSG_POTION_APPLE_JUICE,
		"åץ롦塼" },
	{ N_MSG_POTION_GRAPE_JUICE,
		"졼ס塼" },
	{ N_MSG_POTION_ORANGE_JUICE,
		"󥸡塼" },
	{ N_MSG_POTION_BLACK_BERRY_JUICE,
		"֥å٥꡼塼" },
	{ N_MSG_POTION_CRAN_BERRY_JUICE,
		"٥꡼塼" },
	{ N_MSG_POTION_RASP_BERRY_JUICE,
		"饺٥꡼塼" },
	{ N_MSG_POTION_STRAW_BERRY_JUICE,
		"ȥ٥꡼塼" },
	{ N_MSG_POTION_OIL,
		"" },
	{ N_MSG_POTION_STONE,
		"в" },
	{ N_MSG_POTION_PARALYZE,
		"" },
	{ N_MSG_POTION_POISON,
		"" },
	{ N_MSG_POTION_CONFUSION,
		"" },
	{ N_MSG_POTION_BLIND,
		"ܤ" },
	{ N_MSG_POTION_SLEEP,
		"̲" },
	{ N_MSG_POTION_SILENCE,
		"ۤ" },
	{ N_MSG_POTION_FEAR,
		"ݤ" },
	{ N_MSG_POTION_HALLUCINATION,
		"Ф" },
	{ N_MSG_POTION_CHARM,
		"̥λ" },
	{ N_MSG_POTION_CURE_LEV,
		"٥" },
	{ N_MSG_POTION_CURE_HP_LIGHT,
		"Ͼ" },
	{ N_MSG_POTION_CURE_HP_MODERATE,
		"" },
	{ N_MSG_POTION_CURE_HP_SERIOUS,
		"" },
	{ N_MSG_POTION_CURE_HP_MAX,
		"ϴ" },
	{ N_MSG_POTION_FLY,
		"ͷ" },
	{ N_MSG_POTION_VANISH,
		"Ʃ" },
	{ N_MSG_POTION_CURE_POISON,
		"Ǥ" },
	{ N_MSG_POTION_CURE_STATUS,
		"ֲ" },
	{ N_MSG_POTION_RESI_PHYS,
		"ʪ񹳤" },
	{ N_MSG_POTION_RESI_HEAT,
		"Ǯ񹳤" },
	{ N_MSG_POTION_RESI_COLD,
		"񹳤" },
	{ N_MSG_POTION_RESI_WIND,
		"񹳤" },
	{ N_MSG_POTION_RESI_ACID,
		"ڻ񹳤" },
	{ N_MSG_POTION_RESI_ELEC,
		"񹳤" },
	{ N_MSG_POTION_RESI_POIS,
		"񹳤" },
	{ N_MSG_POTION_SHARPNESS,
		"" },
	{ N_MSG_POTION_DULLNESS,
		"ٸ" },
	{ N_MSG_POTION_STRENGTH,
		"" },
	{ N_MSG_POTION_WEAKNESS,
		"ϸ" },
	{ N_MSG_POTION_QUICKNESS,
		"Ҿ" },
	{ N_MSG_POTION_SLOWNESS,
		"Ҿٸ" },
	{ N_MSG_POTION_WISE,
		"Ƚ" },
	{ N_MSG_POTION_FOOLISH,
		"Ƚϸ" },
	{ N_MSG_POTION_BRAINY,
		"" },
	{ N_MSG_POTION_BRAINLESS,
		"ϸ" },
	{ N_MSG_POTION_ATTRACTIVE,
		"̥" },
	{ N_MSG_POTION_UNATTRACTIVE,
		"̥ϸ" },
	{ N_MSG_POTION_SENSE_INVISIBLE,
		"Ļ벽" },
	{ N_MSG_POTION_POW_UP_HP,
		"" },
	{ N_MSG_POTION_SPEED_UP,
		"®" },
	{ N_MSG_POTION_SPEED_DOWN,
		"®" },
	{ N_MSG_POTION_DETECT_MNSTR,
		"󥹥õΤ" },

	{ N_MSG_POTION_COLOR_CRYSTAL,
		"Ʃ" },
	{ N_MSG_POTION_COLOR_CRYSTAL_WHITE,
		"ȾƩ" },
	{ N_MSG_POTION_COLOR_CRYSTAL_BLACK,
		"ȾƩʹ" },
	{ N_MSG_POTION_COLOR_CRYSTAL_RED,
		"ȾƩֿ" },
	{ N_MSG_POTION_COLOR_CRYSTAL_GREEN,
		"ȾƩп" },
	{ N_MSG_POTION_COLOR_CRYSTAL_BLUE,
		"ȾƩĿ" },
	{ N_MSG_POTION_COLOR_CRYSTAL_YELLOW,
		"ȾƩʲ" },
	{ N_MSG_POTION_COLOR_CRYSTAL_RED_PURPLE,
		"ȾƩֻ翧" },
	{ N_MSG_POTION_COLOR_CRYSTAL_BLUE_PURPLE,
		"ȾƩĻ翧" },
	{ N_MSG_POTION_COLOR_CRYSTAL_ORANGE,
		"ȾƩʥ󥸿" },
	{ N_MSG_POTION_COLOR_CRYSTAL_PINK,
		"ȾƩʥԥ󥯿" },
	{ N_MSG_POTION_COLOR_CRYSTAL_BROWN,
		"ȾƩ㿧" },
	{ N_MSG_POTION_COLOR_WHITE,
		"" },
	{ N_MSG_POTION_COLOR_BLACK,
		"" },
	{ N_MSG_POTION_COLOR_RED,
		"ֿ" },
	{ N_MSG_POTION_COLOR_GREEN,
		"п" },
	{ N_MSG_POTION_COLOR_BLUE,
		"Ŀ" },
	{ N_MSG_POTION_COLOR_YELLOW,
		"" },
	{ N_MSG_POTION_COLOR_RED_PURPLE,
		"ֻ翧" },
	{ N_MSG_POTION_COLOR_BLUE_PURPLE,
		"Ļ翧" },
	{ N_MSG_POTION_COLOR_ORANGE,
		"󥸿" },
	{ N_MSG_POTION_COLOR_PINK,
		"ԥ󥯿" },
	{ N_MSG_POTION_COLOR_BROWN,
		"㿧" },
	{ N_MSG_POTION_COLOR_LUMINOUS_WHITE,
		"ָ" },
	{ N_MSG_POTION_COLOR_LUMINOUS_BLACK,
		"ָι" },
	{ N_MSG_POTION_COLOR_LUMINOUS_RED,
		"ָֿ" },
	{ N_MSG_POTION_COLOR_LUMINOUS_GREEN,
		"ָп" },
	{ N_MSG_POTION_COLOR_LUMINOUS_BLUE,
		"ָĿ" },
	{ N_MSG_POTION_COLOR_LUMINOUS_YELLOW,
		"ָβ" },
	{ N_MSG_POTION_COLOR_LUMINOUS_RED_PURPLE,
		"ָֻ翧" },
	{ N_MSG_POTION_COLOR_LUMINOUS_BLUE_PURPLE,
		"ָĻ翧" },
	{ N_MSG_POTION_COLOR_LUMINOUS_ORANGE,
		"ָΥ󥸿" },
	{ N_MSG_POTION_COLOR_LUMINOUS_PINK,
		"ָΥԥ󥯿" },
	{ N_MSG_POTION_COLOR_LUMINOUS_BROWN,
		"ָ㿧" },
	{ N_MSG_POTION_COLOR_SPOTTED_WHITE,
		"ä" },
	{ N_MSG_POTION_COLOR_SPOTTED_BLACK,
		"äι" },
	{ N_MSG_POTION_COLOR_SPOTTED_RED,
		"äֿ" },
	{ N_MSG_POTION_COLOR_SPOTTED_GREEN,
		"äп" },
	{ N_MSG_POTION_COLOR_SPOTTED_BLUE,
		"äĿ" },
	{ N_MSG_POTION_COLOR_SPOTTED_YELLOW,
		"äβ" },
	{ N_MSG_POTION_COLOR_SPOTTED_RED_PURPLE,
		"äֻ翧" },
	{ N_MSG_POTION_COLOR_SPOTTED_BLUE_PURPLE,
		"äĻ翧" },
	{ N_MSG_POTION_COLOR_SPOTTED_ORANGE,
		"äΥ󥸿" },
	{ N_MSG_POTION_COLOR_SPOTTED_PINK,
		"äΥԥ󥯿" },
	{ N_MSG_POTION_COLOR_SPOTTED_BROWN,
		"ä㿧" },
	{ N_MSG_POTION_COLOR_MILK,
		"ߥ륯" },
	{ N_MSG_POTION_COLOR_WHITE_WINE,
		"磻" },
	{ N_MSG_POTION_COLOR_RED_WINE,
		"֥磻" },
	{ N_MSG_POTION_COLOR_ROSE_WINE,
		"磻" },
	{ N_MSG_POTION_COLOR_ALE,
		"뿧" },
	{ N_MSG_POTION_COLOR_BRANDY,
		"֥ǡ" },
	{ N_MSG_POTION_COLOR_RUM,
		"" },
	{ N_MSG_POTION_COLOR_COFFE,
		"ҡ" },
	{ N_MSG_POTION_COLOR_ICE_COFFE,
		"ҡ" },
	{ N_MSG_POTION_COLOR_TEA,
		"ȥ졼ȡƥ" },
	{ N_MSG_POTION_COLOR_MILK_TEA,
		"ߥ륯ƥ" },
	{ N_MSG_POTION_COLOR_LEMON_TEA,
		"󡦥ƥ" },
	{ N_MSG_POTION_COLOR_ICE_TEA,
		"ƥ" },
	{ N_MSG_POTION_COLOR_ICE_MILK_TEA,
		"ߥ륯ƥ" },
	{ N_MSG_POTION_COLOR_ICE_LEMON_TEA,
		"󡦥ƥ" },
	{ N_MSG_POTION_COLOR_APPLE_JUICE,
		"åץ롦塼" },
	{ N_MSG_POTION_COLOR_GRAPE_JUICE,
		"졼ס塼" },
	{ N_MSG_POTION_COLOR_ORANGE_JUICE,
		"󥸡塼" },
	{ N_MSG_POTION_COLOR_BLACK_BERRY_JUICE,
		"֥å٥꡼塼" },
	{ N_MSG_POTION_COLOR_CRAN_BERRY_JUICE,
		"٥꡼塼" },
	{ N_MSG_POTION_COLOR_RASP_BERRY_JUICE,
		"饺٥꡼塼" },
	{ N_MSG_POTION_COLOR_STRAW_BERRY_JUICE,
		"ȥ٥꡼塼" },

/* Scroll */

	{ N_MSG_SCROLL_SLEEP,
		"̲δʪ" },
	{ N_MSG_SCROLL_IDENTIFY_ITEM,
		"ƥ༱̤δʪ" },
	{ N_MSG_SCROLL_DETECT_ITEM,
		"ƥõΤδʪ" },
	{ N_MSG_SCROLL_TELEPORT,
		"ְִưδʪ" },
	{ N_MSG_SCROLL_POW_UP_WPN_HIT,
		"ι϶δʪ" },
	{ N_MSG_SCROLL_POW_UP_WPN_DAM,
		"Υ᡼δʪ" },
	{ N_MSG_SCROLL_REMOVE_CURSE,
		"δʪ" },
	{ N_MSG_SCROLL_RECALL,
		"Ԥδʪ" },

	{ N_MSG_READ_SCROLL_FAILURE,
		"꤬Ť %s ϴʪɤޤ" },

	{ N_MSG_SCROLL_TTL_SYLLABLE_DIV,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_000,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_001,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_002,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_010,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_011,
		"ꥭ" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_012,
		"Х" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_013,
		"ϥå" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_020,
		"֥" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_021,
		"֥" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_030,
		"ӥӥ" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_031,
		"Хӥ" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_032,
		"֥" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_040,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_041,
		"祦" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_042,
		"ॸ祦" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_050,
		"ʥ" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_051,
		"ߥ" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_052,
		"֥" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_060,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_061,
		"ѥ" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_070,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_071,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_072,
		"å" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_080,
		"ߥ" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_081,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_082,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_090,
		"å" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_091,
		"ɥɥ" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_092,
		"ɥ" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_101,
		"桼" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_102,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_103,
		"ȥ饤" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_104,
		"ƥ" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_110,
		"إ" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_111,
		"쥭" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_120,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_121,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_130,
		"" },
	{ N_MSG_SCROLL_TTL_SYLLABLE_131,
		"" },

/* Stick */

	{ N_MSG_STICK_FAILURE,
		"ʤˤⵯʤä" },

	{ N_MSG_STICK_MATERIAL_APPLEWOOD,
		"󥴤" },
	{ N_MSG_STICK_MATERIAL_ASHEN,
		"Ȥͤꤳ" },
	{ N_MSG_STICK_MATERIAL_ASPEN,
		"ݥץ" },
	{ N_MSG_STICK_MATERIAL_AVOCADO_WOOD,
		"ܥɤ" },
	{ N_MSG_STICK_MATERIAL_BALSA,
		"Х륵" },
	{ N_MSG_STICK_MATERIAL_BANYAN,
		"Х" },
	{ N_MSG_STICK_MATERIAL_BIRCH,
		"Ф" },
	{ N_MSG_STICK_MATERIAL_CEDAR,
		"" },
	{ N_MSG_STICK_MATERIAL_CHERRYWOOD,
		"" },
	{ N_MSG_STICK_MATERIAL_COTTONWOOD,
		"ϤҤϤʤ" },
	{ N_MSG_STICK_MATERIAL_CYPRESS,
		"Ȥ" },
	{ N_MSG_STICK_MATERIAL_DOGWOOD,
		"ߤ" },
	{ N_MSG_STICK_MATERIAL_DRIFTWOOD,
		"ή" },
	{ N_MSG_STICK_MATERIAL_EBONY,
		"" },
	{ N_MSG_STICK_MATERIAL_ELM_WOOD,
		"ˤ" },
	{ N_MSG_STICK_MATERIAL_EUCALYPTUS,
		"桼" },
	{ N_MSG_STICK_MATERIAL_GRAPEVINE,
		"֤ɤ" },
	{ N_MSG_STICK_MATERIAL_HAWTHORN,
		"󤶤" },
	{ N_MSG_STICK_MATERIAL_HEMLOCK,
		"Ĥ" },
	{ N_MSG_STICK_MATERIAL_HICKORY,
		"ҥå꡼" },
	{ N_MSG_STICK_MATERIAL_JUNIPER,
		"Τͤ" },
	{ N_MSG_STICK_MATERIAL_LOCUST,
		"ˤ" },
	{ N_MSG_STICK_MATERIAL_MAHOGANY,
		"ޥۥˡ" },
	{ N_MSG_STICK_MATERIAL_MAGNOLIA,
		"⤯" },
	{ N_MSG_STICK_MATERIAL_MAPLE,
		"Ǥ" },
	{ N_MSG_STICK_MATERIAL_MULBERRY,
		"" },
	{ N_MSG_STICK_MATERIAL_OAK,
		"" },
	{ N_MSG_STICK_MATERIAL_PECAN,
		"ڤ" },
	{ N_MSG_STICK_MATERIAL_PERSIMMON,
		"" },
	{ N_MSG_STICK_MATERIAL_PINE,
		"" },
	{ N_MSG_STICK_MATERIAL_REDWOOD,
		"" },
	{ N_MSG_STICK_MATERIAL_ROSEWOOD,
		"ɤ" },
	{ N_MSG_STICK_MATERIAL_SPRUCE,
		"ȤҤ" },
	{ N_MSG_STICK_MATERIAL_SUMAC,
		"뤷" },
	{ N_MSG_STICK_MATERIAL_SYCAMORE,
		"礫Ǥ" },
	{ N_MSG_STICK_MATERIAL_TEAK,
		"" },
	{ N_MSG_STICK_MATERIAL_WALNUT,
		"" },

/* Accecery */

	{ N_MSG_RING_SLOW_DIGESTION,
		"ò٤" },
	{ N_MSG_RING_TELEPORT_PARTY,
		"ѡƥְִưλ" },
	{ N_MSG_RING_TELEPORT,
		"ְִưλ" },
	{ N_MSG_AMULET_RESI_PHYS,
		"ʪ񹳤" },
	{ N_MSG_AMULET_RESI_HEAT,
		"Ǯ񹳤" },
	{ N_MSG_AMULET_RESI_COLD,
		"񹳤" },
	{ N_MSG_AMULET_RESI_WIND,
		"񹳤" },
	{ N_MSG_AMULET_RESI_ACID,
		"ڻ񹳤" },
	{ N_MSG_AMULET_RESI_ELEC,
		"񹳤" },
	{ N_MSG_AMULET_RESI_POIS,
		"񹳤" },

	{ N_MSG_RING_MATERIAL_ALUMINUM,
		"ߥ˥" },
	{ N_MSG_RING_MATERIAL_BONE,
		"" },
	{ N_MSG_RING_MATERIAL_BRASS,
		"夦" },
	{ N_MSG_RING_MATERIAL_BRONZE,
		"Ƽ" },
	{ N_MSG_RING_MATERIAL_CAST_IRON,
		"Ŵ" },
	{ N_MSG_RING_MATERIAL_CHROMIUM,
		"" },
	{ N_MSG_RING_MATERIAL_COPPER,
		"Ƽ" },
	{ N_MSG_RING_MATERIAL_GOLD,
		"" },
	{ N_MSG_RING_MATERIAL_IRON,
		"Ŵ" },
	{ N_MSG_RING_MATERIAL_LEAD,
		"" },
	{ N_MSG_RING_MATERIAL_MAGNESIUM,
		"ޥͥ" },
	{ N_MSG_RING_MATERIAL_MOLYBDENUM,
		"֥ǥ" },
	{ N_MSG_RING_MATERIAL_NICKEL,
		"˥å" },
	{ N_MSG_RING_MATERIAL_PEWTER,
		"" },
	{ N_MSG_RING_MATERIAL_SILVER,
		"" },
	{ N_MSG_RING_MATERIAL_STEEL,
		"" },
	{ N_MSG_RING_MATERIAL_TIN,
		"" },
	{ N_MSG_RING_MATERIAL_TITANIUM,
		"" },
	{ N_MSG_RING_MATERIAL_TUNGSTEN,
		"󥰥ƥ" },
	{ N_MSG_RING_MATERIAL_ZINC,
		"" },
	{ N_MSG_RING_MATERIAL_ZIRCONIUM,
		"륳˥" },

#if	0
@@@
	{ N_MSG_RING_GEM_AMBER,
		"Ϥ" },
	{ N_MSG_RING_GEM_AGATE,
		"Τ" },
	{ N_MSG_RING_GEM_ALEXANDRITE,
		"" },
	{ N_MSG_RING_GEM_AMETHYST,
		"徽" },
	{ N_MSG_RING_GEM_ANTLERITE,
		"" },
	{ N_MSG_RING_GEM_AQUAMARINE,
		"" },
	{ N_MSG_RING_GEM_ARGENTITE,
		"" },
	{ N_MSG_RING_GEM_AZURITE,
		"" },
	{ N_MSG_RING_GEM_BERYL,
		"" },
	{ N_MSG_RING_GEM_BLOODSTONE,
		"" },
	{ N_MSG_RING_GEM_CALCITE,
		"" },
	{ N_MSG_RING_GEM_CARNELIAN,
		"ȶ̿" },
	{ N_MSG_RING_GEM_CORAL,
		"" },
	{ N_MSG_RING_GEM_CORUNDUM,
		"Ƽ" },
	{ N_MSG_RING_GEM_CRYOLITE,
		"" },
	{ N_MSG_RING_GEM_DIAMOND,
		"" },
	{ N_MSG_RING_GEM_DIORITE,
		"" },
	{ N_MSG_RING_GEM_EMERALD,
		"" },
	{ N_MSG_RING_GEM_FLINT,
		"Ǥ" },
	{ N_MSG_RING_GEM_FLUORITE,
		"" },
	{ N_MSG_RING_GEM_GABBRO,
		"" },
	{ N_MSG_RING_GEM_GARNET,
		"" },
	{ N_MSG_RING_GEM_GRANITE,
		"ߤ" },
	{ N_MSG_RING_GEM_GYPSUM,
		"Ф" },
	{ N_MSG_RING_GEM_HEMATITE,
		"" },
	{ N_MSG_RING_GEM_JADE,
		"Ҥ" },
	{ N_MSG_RING_GEM_JASPER,
		"˶" },
	{ N_MSG_RING_GEM_KRYPTONITE,
		"" },
	{ N_MSG_RING_GEM_LAPIS_LAZULI,
		"" },
	{ N_MSG_RING_GEM_LIMESTONE,
		"" },
	{ N_MSG_RING_GEM_MALACHITE,
		"" },
	{ N_MSG_RING_GEM_MANGANITE,
		"" },
	{ N_MSG_RING_GEM_MARBLE,
		"" },
	{ N_MSG_RING_GEM_MOONSTONE,
		"" },
	{ N_MSG_RING_GEM_NEPTUNITE,
		"" },
	{ N_MSG_RING_GEM_OBSIDIAN,
		"" },
	{ N_MSG_RING_GEM_ONYX,
		"" },
	{ N_MSG_RING_GEM_OPAL,
		"" },
	{ N_MSG_RING_GEM_PEARL,
		"" },
	{ N_MSG_RING_GEM_PYRITE,
		"" },
	{ N_MSG_RING_GEM_QUARTZ,
		"" },
	{ N_MSG_RING_GEM_QUARTZITE,
		"" },
	{ N_MSG_RING_GEM_RHODONITE,
		"" },
	{ N_MSG_RING_GEM_RHYOLITE,
		"" },
	{ N_MSG_RING_GEM_RUBY,
		"" },
	{ N_MSG_RING_GEM_SAPPHIRE,
		"" },
	{ N_MSG_RING_GEM_SPHALERITE,
		"" },
	{ N_MSG_RING_GEM_STAUROLITE,
		"" },
	{ N_MSG_RING_GEM_TIGER_EYE,
		"" },
	{ N_MSG_RING_GEM_TOPAZ,
		"" },
	{ N_MSG_RING_GEM_TURQUOISE,
		"" },
	{ N_MSG_RING_GEM_ZIRCON,
		"" },
#endif

/* Light */

	{ N_MSG_LIGHT_TORCH,
		"ޤ" },
	{ N_MSG_LIGHT_LANTERN,
		"󥿥" },
	{ N_MSG_LIGHT_LAMP,
		"" },

/* Spike */

	{ N_MSG_SPIKE,
		"ţ" },

/* Food */

	{ N_MSG_FOOD_PRESERVED,
		"¸" },
	{ N_MSG_FOOD_CHIPPED_BEEF,
		"" },
	{ N_MSG_FOOD_CORNED_BEEF,
		"ӡ" },
	{ N_MSG_FOOD_BREAD,
		"ѥ" },
	{ N_MSG_FOOD_BROWN_BREAD,
		"ѥ" },
	{ N_MSG_FOOD_TOAST,
		"ȡ" },
	{ N_MSG_FOOD_PANCAKE,
		"ѥ󥱡" },
	{ N_MSG_FOOD_SALAD,
		"" },
	{ N_MSG_FOOD_POTATO_SALAD,
		"ݥƥȡ" },
	{ N_MSG_FOOD_SCRAMBLED_EGGS,
		"֥롦å" },
	{ N_MSG_FOOD_FRIED_EGGS,
		"ܶ̾" },
	{ N_MSG_FOOD_HARD_BOILED_EGGS,
		"" },
	{ N_MSG_FOOD_SOFT_BOILED_EGGS,
		"Ⱦ" },
	{ N_MSG_FOOD_BEEF_STEAK,
		"ӡաơ" },
	{ N_MSG_FOOD_PORK_SAUTE,
		"ݡơ" },
	{ N_MSG_FOOD_FRIED_CHICKEN,
		"ե饤ɡ" },
	{ N_MSG_FOOD_FRIED_FISH,
		"ե饤ɡեå" },
	{ N_MSG_FOOD_FRIED_POTATO,
		"ե饤ɡݥƥ" },
	{ N_MSG_FOOD_STEWED_BEEF,
		"ӡա塼" },
	{ N_MSG_FOOD_CONSOMME,
		"󥽥ᡦ" },
	{ N_MSG_FOOD_POTAGE,
		"ݥ" },
	{ N_MSG_FOOD_APPLE_PIE,
		"åץ롦ѥ" },
	{ N_MSG_FOOD_APPLE,
		"" },
	{ N_MSG_FOOD_GRAPE,
		"֤ɤ" },
	{ N_MSG_FOOD_ORANGE,
		"" },
	{ N_MSG_FOOD_PEAR,
		"" },
	{ N_MSG_FOOD_GRAPEFRUIT,
		"졼ץե롼" },
	{ N_MSG_FOOD_PLUM,
		"ץ" },
	{ N_MSG_FOOD_PEACH,
		"" },
	{ N_MSG_FOOD_APRICOT,
		"ץꥳå" },
	{ N_MSG_FOOD_BLACK_BERRY,
		"֥å٥꡼" },
	{ N_MSG_FOOD_CRAN_BERRY,
		"٥꡼" },
	{ N_MSG_FOOD_RASP_BERRY,
		"饺٥꡼" },
	{ N_MSG_FOOD_STRAW_BERRY,
		"ȥ٥꡼" },

/* Chest */

	{ N_MSG_CHEST,
		"Ȣ" },

/* Tobacco */

	{ N_MSG_TOBACCO_CIGARET,
		"洬Х" },
	{ N_MSG_TOBACCO_CIGAR,
		"մ" },
	{ N_MSG_TOBACCO_CUT_TOBACCO,
		"ѥѹߥХ" },
	{ N_MSG_TOBACCO_SNUFF_TOBACCO,
		"Х" },
	{ N_MSG_TOBACCO_CHEWING_TOBACCO,
		"ߥХ" },
	{ N_MSG_TOBACCO_ABSTAIN_GUM,
		"ر쥬" },

/* CIGARET */
	{ N_MSG_TOBACCO_BRAND_HELLO,
		"HELLO" },
	{ N_MSG_TOBACCO_BRAND_SUN_SHINE,
		"SUN SHINE" },
	{ N_MSG_TOBACCO_BRAND_CHERRY_TREE,
		"CHERRY TREE" },
	{ N_MSG_TOBACCO_BRAND_GOLDEN_RAT,
		"GOLDEN RAT" },
	{ N_MSG_TOBACCO_BRAND_AIR_SHIT,
		"AIR SHIT" },
	{ N_MSG_TOBACCO_BRAND_HOP,
		"HOP" },
	{ N_MSG_TOBACCO_BRAND_PIECE,
		"PIECE" },
	{ N_MSG_TOBACCO_BRAND_HARPY,
		"HARPY" },
	{ N_MSG_TOBACCO_BRAND_HIGH_LIGHT,
		"HIGH LIGHT" },
	{ N_MSG_TOBACCO_BRAND_SHOOTING_STARS,
		"SHOOTING STARS" },
	{ N_MSG_TOBACCO_BRAND_WILD_NINE,
		"WILD NINE" },
	{ N_MSG_TOBACCO_BRAND_WILD_NINE_MENTHOL,
		"WILD NINE MENTHOL" },
	{ N_MSG_TOBACCO_BRAND_LODGE,
		"LODGE" },
	{ N_MSG_TOBACCO_BRAND_LODGE_MENTHOL,
		"LODGE MENTHOL" },
	{ N_MSG_TOBACCO_BRAND_CANCER,
		"CANCER" },
	{ N_MSG_TOBACCO_BRAND_CANCER_MENTHOL,
		"CANCER MENTHOL" },
	{ N_MSG_TOBACCO_BRAND_FRONT_LINE,
		"FRONT LINE" },
	{ N_MSG_TOBACCO_BRAND_FRONT_LINE_MENTHOL,
		"FRONT LINE MENTHOL" },
	{ N_MSG_TOBACCO_BRAND_MARCO_POLO,
		"MARCO POLO" },
	{ N_MSG_TOBACCO_BRAND_CAMELLIA,
		"CAMELLIA" },
	{ N_MSG_TOBACCO_BRAND_GOOD_LUCK,
		"GOOD LUCK" },
	{ N_MSG_TOBACCO_BRAND_BAD_GUY,
		"BAD GUY" },

/* CIGAR */
	{ N_MSG_TOBACCO_BRAND_ARCADIA,
		"ARCADIA" },
	{ N_MSG_TOBACCO_BRAND_GLORIA,
		"GLORIA" },
	{ N_MSG_TOBACCO_BRAND_VULCAN,
		"VULCAN" },
	{ N_MSG_TOBACCO_BRAND_PONY,
		"PONY" },
	{ N_MSG_TOBACCO_BRAND_KEITH,
		"KEITH" },
	{ N_MSG_TOBACCO_BRAND_LUMBERJACK,
		"LUMBERJACK" },
	{ N_MSG_TOBACCO_BRAND_CORONA,
		"CORONA" },
	{ N_MSG_TOBACCO_BRAND_HALF_CORONA,
		"HALF CORONA" },
	{ N_MSG_TOBACCO_BRAND_CRYSTAL,
		"CRYSTAL" },

/* CUT TOBACCO */
	{ N_MSG_TOBACCO_BRAND_FOREST_BRANDY,
		"FOREST BRANDY" },
	{ N_MSG_TOBACCO_BRAND_SILK_ROAD,
		"SILK ROAD" },
	{ N_MSG_TOBACCO_BRAND_PROMENADE,
		"PROMENADE" },
	{ N_MSG_TOBACCO_BRAND_BIG_HORN,
		"BIG HORN" },
	{ N_MSG_TOBACCO_BRAND_ROCKING_CHAIR,
		"ROCKING CHAIR" },
	{ N_MSG_TOBACCO_BRAND_VANILLA,
		"VANILLA" },
	{ N_MSG_TOBACCO_BRAND_WILD_MANGO,
		"WILD MANGO" },
	{ N_MSG_TOBACCO_BRAND_KENTUCKY_BIRD,
		"KENTUCKY BIRD" },
	{ N_MSG_TOBACCO_BRAND_ORIENT,
		"ORIENT" },
	{ N_MSG_TOBACCO_BRAND_FUJI,
		"FUJI" },

/* SNUFF TOBACCO */
	{ N_MSG_TOBACCO_BRAND_DOGGY_APRICOT,
		"DOGGY APRICOT" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_WHISKY,
		"DOGGY WHISKY" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_HONEY,
		"DOGGY HONEY" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_SPEARMINT,
		"DOGGY SPEARMINT" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_PEPPERMINT,
		"DOGGY PEPPERMINT" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_VANILLA,
		"DOGGY VANILLA" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_MENTHOL,
		"DOGGY MENTHOL" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_CITRUS,
		"DOGGY CITRUS" },
	{ N_MSG_TOBACCO_BRAND_DOGGY_SHERRY,
		"DOGGY SHERRY" },

/* CHEWING TOBACCO */
	{ N_MSG_TOBACCO_BRAND_ROSE_PREMIUM,
		"ROSE PREMIUM" },
	{ N_MSG_TOBACCO_BRAND_ROSE_VANILLA,
		"ROSE VANILLA" },
	{ N_MSG_TOBACCO_BRAND_ROSE_MENTHOL,
		"ROSE MENTHOL" },

/* ABSTAIN GUM */
	{ N_MSG_TOBACCO_BRAND_NICOTIME,
		"NICOTIME" },

/* STUB */
	{ N_MSG_TOBACCO_STUB,
		"Хε۳" },

/* PIPE */
	{ N_MSG_PIPE_PIPE,
		"ѥ" },
	{ N_MSG_PIPE_KISEL,
		"" },
	{ N_MSG_PIPE_CIGARET_HOLDER,
		"洬Хѥѥ" },
	{ N_MSG_PIPE_STUB,
		"ѺѤߥѥ" },

	{ N_MSG_SMOKE_FAILURE,
		"ѥפƲ" },

/* Gold */

	{ N_MSG_COIN_GOLD,
		STR_GOLD },
	{ N_MSG_COIN_SILVER,
		"" },
	{ N_MSG_COIN_COPPER,
		"Ƽ" },

/* misc */

	{ N_MSG_JUNK,
		"߶" },

/**/

	{ N_MSG_TRGT,
		"ɸ" },

/* mbr act */

	{ N_MSG_DOWN_DUN,
		"ʤ򲼤ꤿ" },
	{ N_MSG_UP_DUN,
		"ʤä" },

	{ N_MSG_COLLECT_GOLD,
		"%s  %ld " STR_GOLD "᤿" },
	{ N_MSG_DIVIDE_GOLD,
		"ƥС %ld " STR_GOLD "Ťʬä" },
	{ N_MSG_NOT_FRIEND_GOLD,
		"%s " STR_GOLD "ΤȤǤä" },

	{ N_MSG_STOMACH_FULL,
		"%s ϤʢäѤˤʤä" },

	{ N_MSG_DOOR_OPEN,
		"%s ϥɥ򳫤" },
	{ N_MSG_DOOR_CLOSE,
		"%s ϥɥĤ" },
	{ N_MSG_DOOR_JAM,
		"%s ϥɥꤷ" },
	{ N_MSG_DOOR_DISARM,
		"%s ϥɥθ" STR_DISARM "" },
	{ N_MSG_DOOR_BREAK,
		"%s ϥɥ" },
	{ N_MSG_DOOR_SRCH,
		"%s ϥɥȯ" },

	{ N_MSG_SRCH_DOOR_SHOP,
		"%s ΥɥǤ" },
	{ N_MSG_SRCH_DOOR_OPEN,
		"ΥɥϳƤޤ" },
	{ N_MSG_SRCH_DOOR_CLOSE,
		"ΥɥĤƤޤ" },
	{ N_MSG_SRCH_DOOR_JAMMED,
		"ΥɥϸꤵƤޤ" },
	{ N_MSG_SRCH_DOOR_BROKEN,
		"ΥɥϲƤޤ" },

	{ N_MSG_TRAP_DISARM,
		"%s 櫤" STR_DISARM "" },
	{ N_MSG_TRAP_BREAK,
		"%s 櫤" },

	{ N_MSG_SRCH_TRAP,
		" %s 櫤Ǥ" },

	{ N_MSG_ITEM_PICK_UP,
		"%s  %s 򽦤ä" },
	{ N_MSG_ITEM_OPEN,
		"%s  %s 򳫤" },
	{ N_MSG_ITEM_DISARM,
		"%s  %s Υ" STR_DISARM "" },
	{ N_MSG_ITEM_BREAK,
		"%s  %s " },
	{ N_MSG_SRCH_ITEM,
		" %s " },

	{ N_MSG_READY_THROW_CHEST,
		"%s ˲äƤ" },

	{ N_MSG_DONT_EXHIBIT_ABL_EQUIP,
		"%s Τ %s ǽϤȯǤʤ" },

	{ N_MSG_ERR_HP_SHORT,
		"%s  HP  %ld ­ʤ" },
	{ N_MSG_ERR_MP_SHORT,
		"%s  MP  %ld ­ʤ" },

/* FX */

	{ N_MSG_FX_QUAFF_POTION,
		"%s  %s " },
	{ N_MSG_FX_READ_SCROLL,
		"%s  %s ɤ" },
	{ N_MSG_FX_ZAP_STICK,
		"%s  %s ä" },

	{ N_MSG_FX_STONE,
		"%s ФˤʤäƤޤä" },
	{ N_MSG_FX_PARALYZE,
		"%s 㤷Ƥޤä" },
	{ N_MSG_FX_POISON,
		"%s Ǥ줿" },
	{ N_MSG_FX_CONFUSION,
		"%s Ϻ𤷤Ƥޤä" },
	{ N_MSG_FX_BLIND,
		"%s ܤʤʤäƤޤä" },
	{ N_MSG_FX_SLEEP,
		"%s ̲äƤޤä" },
	{ N_MSG_FX_SILENCE,
		"%s ʤʤä" },
	{ N_MSG_FX_FEAR,
		"%s ϶ݤ˼Ĥ줿" },
	{ N_MSG_FX_HALLUCINATION,
		"%s ϸФ˽줿" },
	{ N_MSG_FX_CHARM,
		"%s ̥λ줿" },
	{ N_MSG_FX_FLY,
		"%s Τ⤫Ӿ夬ä" },
	{ N_MSG_FX_VANISH,
		"%s ΤƩˤʤä" },
	{ N_MSG_FX_DRUNK,
		"%s ϿäѤä" },

	{ N_MSG_FX_RESI_PHYS,
		"%s ϶ˤȤ줿" },
	{ N_MSG_FX_RESI_WIND,
		"%s ϿϤ褤򴶤" },
	{ N_MSG_FX_RESI_HEAT,
		"%s äʤä" },
	{ N_MSG_FX_RESI_COLD,
		"%s Ȥʤä" },
	{ N_MSG_FX_RESI_ELEC,
		"%s ŵä" },
	{ N_MSG_FX_RESI_ACID,
		"%s ȩ٥٤ˤʤä" },
	{ N_MSG_FX_RESI_POIS,
		"%s ϵɤʤä" },

	{ N_MSG_FX_SHARPNESS,
		"%s Τפɤư" },
	{ N_MSG_FX_DULLNESS,
		"%s Τפɤưʤ" },
	{ N_MSG_FX_STRENGTH,
		"%s Ϥߤʤä" },
	{ N_MSG_FX_WEAKNESS,
		"%s Ϥȴ" },
	{ N_MSG_FX_QUICKNESS,
		"%s Τڤ" },
	{ N_MSG_FX_SLOWNESS,
		"%s ΤŤ" },
	{ N_MSG_FX_WISE,
		"%s ϸʤä" },
	{ N_MSG_FX_FOOLISH,
		"%s ϶򤫤ˤʤäƤޤä" },
	{ N_MSG_FX_BRAINY,
		"%s Ƭɤʤä" },
	{ N_MSG_FX_BRAINLESS,
		"%s ƬʤäƤޤä" },
	{ N_MSG_FX_ATTRACTIVE,
		"%s ʤä" },
	{ N_MSG_FX_UNATTRACTIVE,
		"%s ϽʤäƤޤä" },

	{ N_MSG_FX_WATER,
		"%s Ϲ뤪ä" },
	{ N_MSG_FX_OIL,
		"" },
	{ N_MSG_FX_CURE_LEV,
		"%s ΤפФ" },
	{ N_MSG_FX_CURE_HP_LIGHT,
		"%s Ͻä" },
	{ N_MSG_FX_CURE_HP_MODERATE,
		"%s Ͻּä" },
	{ N_MSG_FX_CURE_HP_SERIOUS,
		"%s Ͻʤ꼣ä" },
	{ N_MSG_FX_CURE_HP_MAX,
		"%s Ͻ˼ä" },
	{ N_MSG_FX_CURE_POISON,
		"%s Ǥޤä" },
	{ N_MSG_FX_CURE_STATUS,
		"%s ϵʬɤʤä" },
	{ N_MSG_FX_CREATE_FOOD,
		"%s  %s " },
	{ N_MSG_FX_DETECT_MNSTR,
		"%s ϥ󥹥εۤ򴶤" },
	{ N_MSG_FX_DETECT_ITEM,
		"%s ϥƥΰ֤򴶤" },
	{ N_MSG_FX_POW_UP_HP,
		"%s ϥդˤʤä" },
	{ N_MSG_FX_SPEED_UP,
		"%s ư®ʤä" },
	{ N_MSG_FX_SPEED_DOWN,
		"%s ư٤ʤä" },
	{ N_MSG_FX_SENSE_INVISIBLE,
		"%s ܤɤʤäͤ" },
	{ N_MSG_FX_TELEPORT_PARTY,
		"ηʿޤѤä" },
	{ N_MSG_FX_TELEPORT,
		"%s μηʿޤѤä" },
	{ N_MSG_FX_RECALL,
		"㡼.." },
	{ N_MSG_FX_TOBACCO_ABSTAIN,
		"%s ϥХۤʤä" },
	{ N_MSG_FX_SMOKE_TOBACCO,
		"򹯤Τۤ᤮դޤ礦" },
	{ N_MSG_FX_SMOKE_END,
		"%s ϥХۤä" },
	{ N_MSG_FX_BREAK_PIPE,
		"%s  %s ϻȤä" },

	{ N_MSG_FX_IDENTIFY_ITEM,
		"ɤΥƥ̤ޤ? ([ESC]:󥻥)" },
	{ N_MSG_FX_RECALL_ASK,
		"عԤΤ?" },

	{ N_MSG_FX_SLEEP_SUCCESS,
		"%s μϤΥ󥹥̲äƤޤä" },
	{ N_MSG_FX_SLEEP_FAILURE,
		"%s »򤷤ͤʵˤʤä" },
	{ N_MSG_FX_POW_UP_WPN_HIT_SUCCESS,
		"%s 郎פʤä" },
	{ N_MSG_FX_POW_UP_WPN_HIT_FAILURE,
		"%s ξ꤬Ĥä" },
	{ N_MSG_FX_POW_UP_WPN_CRTCL_SUCCESS,
		"%s Υƥ뤬Ф䤹ʤä" },
	{ N_MSG_FX_POW_UP_WPN_CRTCL_FAILURE,
		"%s ξ꤬Ĥä" },
	{ N_MSG_FX_POW_UP_WPN_DAM_SUCCESS,
		"%s Υ᡼礭ʤä" },
	{ N_MSG_FX_POW_UP_WPN_DAM_FAILURE,
		"%s ξ꤬Ĥä" },
	{ N_MSG_FX_REMOVE_CURSE_SUCCESS,
		"%s μ򤱤" },
	{ N_MSG_FX_REMOVE_CURSE_FAILURE,
		"%s äѤϤʤ" },

/* FX CLR */

	{ N_MSG_CLR_FX_STONE,
		"%s ȤΤä" },
	{ N_MSG_CLR_FX_PARALYZE,
		"%s ϤӤ줬ä" },
	{ N_MSG_CLR_FX_POISON,
		"%s Ǥޤä" },
	{ N_MSG_CLR_FX_CONFUSION,
		"%s Ϻ𤬼ޤä" },
	{ N_MSG_CLR_FX_BLIND,
		"%s ܤͤˤʤä" },
	{ N_MSG_CLR_FX_SLEEP,
		"%s ܤФ᤿" },
	{ N_MSG_CLR_FX_SILENCE,
		"%s ͤˤʤä" },
	{ N_MSG_CLR_FX_FEAR,
		"%s ϶̵ʤä" },
	{ N_MSG_CLR_FX_HALLUCINATION,
		"%s ϸФޤä" },
	{ N_MSG_CLR_FX_CHARM,
		"%s ϼ" },
	{ N_MSG_CLR_FX_FLY,
		"%s Ϥ" },
	{ N_MSG_CLR_FX_DRUNK,
		"%s Ͽ줤᤿" },
	{ N_MSG_CLR_FX_VANISH,
		"%s Τͤˤʤä" },

	{ N_MSG_CLR_FX_RESI_KNOC,
		"%s ᡹ˤ" },
	{ N_MSG_CLR_FX_RESI_SLAS,
		"%s ᡹ˤ" },
	{ N_MSG_CLR_FX_RESI_STIN,
		"%s ᡹ˤ" },
	{ N_MSG_CLR_FX_RESI_HEAT,
		"%s Ͼ뤤" },
	{ N_MSG_CLR_FX_RESI_COLD,
		"%s ϴ" },
	{ N_MSG_CLR_FX_RESI_WIND,
		"%s ©줷ʤä" },
	{ N_MSG_CLR_FX_RESI_ACID,
		"%s Τҥҥꤹ" },
	{ N_MSG_CLR_FX_RESI_ELEC,
		"%s ŵѥѥ" },
	{ N_MSG_CLR_FX_RESI_POIS,
		"%s ϵʤä" },

	{ N_MSG_CLR_FX_SHARPNESS,
		"%s Τפɤưʤ" },
	{ N_MSG_CLR_FX_DULLNESS,
		"%s Τפɤư" },
	{ N_MSG_CLR_FX_STRENGTH,
		"%s Ϥȴ" },
	{ N_MSG_CLR_FX_WEAKNESS,
		"%s Ϥߤʤä" },
	{ N_MSG_CLR_FX_QUICKNESS,
		"%s ΤŤ" },
	{ N_MSG_CLR_FX_SLOWNESS,
		"%s Τڤ" },
	{ N_MSG_CLR_FX_WISE,
		"%s ϶򤫤ˤʤäƤޤä" },
	{ N_MSG_CLR_FX_FOOLISH,
		"%s ϸʤä" },
	{ N_MSG_CLR_FX_BRAINY,
		"%s ƬʤäƤޤä" },
	{ N_MSG_CLR_FX_BRAINLESS,
		"%s Ƭɤʤä" },
	{ N_MSG_CLR_FX_ATTRACTIVE,
		"%s ϽʤäƤޤä" },
	{ N_MSG_CLR_FX_UNATTRACTIVE,
		"%s ʤä" },

	{ N_MSG_CLR_FX_SENSE_INVISIBLE,
		"%s ܤʤäͤ" },
	{ N_MSG_CLR_FX_POW_UP_HP,
		"%s ϤҼˤʤä" },
	{ N_MSG_CLR_FX_SPEED,
		"%s ϸ®ä" },

/* ̣ʪ */

	{ N_MSG_FX_DRINK_A00,
		"̣ %s " },
	{ N_MSG_FX_DRINK_A01,
		" %s ϡΤɤɤ" },
	{ N_MSG_FX_DRINK_A02,
		" %s Ͼʤʹ꤬" },
	{ N_MSG_FX_DRINK_A03,
		" %s Ͼʤ̣" },
	{ N_MSG_FX_DRINK_A04,
		" %s ϸ̣ɤ" },
	{ N_MSG_FX_DRINK_A05,
		"Ϥޤ䤫 %s " },

/* ޤʪ */

	{ N_MSG_FX_DRINK_B00,
		"Ϥޤ %s " },

/* ̣ʪ */

	{ N_MSG_FX_EAT_FOOD_A00,
		"̣ %s " },
	{ N_MSG_FX_EAT_FOOD_A01,
		"ޤäȤ %s " },
	{ N_MSG_FX_EAT_FOOD_A02,
		" %s " },
	{ N_MSG_FX_EAT_FOOD_A03,
		"äȤ %s " },
	{ N_MSG_FX_EAT_FOOD_A04,
		"äƤȤ %s " },
	{ N_MSG_FX_EAT_FOOD_A05,
		"Ĥʤ̣ %s " },
	{ N_MSG_FX_EAT_FOOD_A06,
		"Ͽ̣襤Τ %s " },
	{ N_MSG_FX_EAT_FOOD_A07,
		"ϵˤ %s " },
	{ N_MSG_FX_EAT_FOOD_A08,
		"ϻ %s " },

/* ޤʪ */

	{ N_MSG_FX_EAT_FOOD_B00,
		"Ϥޤ %s " },
	{ N_MSG_FX_EAT_FOOD_B01,
		" %s ϡḤ̂" },
	{ N_MSG_FX_EAT_FOOD_B02,
		"ʤ %s ! ĹƤ!" },

/* mnstr */

	{ N_MSG_MNSTR_UNKNOWN,
		"Υ󥹥" },
	{ N_MSG_MNSTR_GIANT_BAT,
		"㥤ȡХå" },
	{ N_MSG_MNSTR_GIANT_RAT,
		"㥤ȡå" },
	{ N_MSG_MNSTR_MIMIC,
		"ߥߥå" },
#if	0
	{ N_MSG_MNSTR_ANCIENT_BLACK_DRAGON,
		"󥷥ȡ֥åɥ饴" },
	{ N_MSG_MNSTR_ANCIENT_BLUE_DRAGON,
		"󥷥ȡ֥롼ɥ饴" },
	{ N_MSG_MNSTR_ANCIENT_RED_DRAGON,
		"󥷥ȡåɡɥ饴" },
	{ N_MSG_MNSTR_ANCIENT_WHITE_DRAGON,
		"󥷥ȡۥ磻ȡɥ饴" },
	{ N_MSG_MNSTR_ANCIENT_YELLOW_DRAGON,
		"󥷥ȡɥ饴" },
	{ N_MSG_MNSTR_MINOR_BLACK_DRAGON,
		"ޥʡ֥åɥ饴" },
	{ N_MSG_MNSTR_MINOR_BLUE_DRAGON,
		"ޥʡ֥롼ɥ饴" },
	{ N_MSG_MNSTR_MINOR_RED_DRAGON,
		"ޥʡåɡɥ饴" },
	{ N_MSG_MNSTR_MINOR_WHITE_DRAGON,
		"ޥʡۥ磻ȡɥ饴" },
	{ N_MSG_MNSTR_MINOR_YELLOW_DRAGON,
		"ޥʡɥ饴" },
	{ N_MSG_MNSTR_BEHEMOTH,
		"ӥҥ⥹" },
	{ N_MSG_MNSTR_SALAMANDER,
		"ޥ" },
	{ N_MSG_MNSTR_BANSHEE,
		"Х󥷡" },
	{ N_MSG_MNSTR_DJINNI,
		"" },
	{ N_MSG_MNSTR_EFREET,
		"ե꡼" },
	{ N_MSG_MNSTR_GNOME,
		"Ρ" },
	{ N_MSG_MNSTR_BROWNIE,
		"֥饦ˡ" },
	{ N_MSG_MNSTR_PHOENIX,
		"ե˥å" },
	{ N_MSG_MNSTR_SYLPH,
		"" },
	{ N_MSG_MNSTR_UNDINE,
		"ǥ" },
	{ N_MSG_MNSTR_WILL_O_WISP,
		"롦" },
	{ N_MSG_MNSTR_COATL,
		"ȥ" },
	{ N_MSG_MNSTR_NAGA,
		"ʡ" },
	{ N_MSG_MNSTR_LYCANTHROPE,
		"饤󥹥" },
	{ N_MSG_MNSTR_MINOTAUR,
		"ߥΥ" },
	{ N_MSG_MNSTR_SATYR,
		"ƥ" },
	{ N_MSG_MNSTR_ANDRO_SCORPION,
		"ɥԥ" },
	{ N_MSG_MNSTR_BIRD_MAN,
		"Сɥޥ" },
	{ N_MSG_MNSTR_CENTAUR,
		"󥿥" },
	{ N_MSG_MNSTR_MEDUSA,
		"ǥ塼" },
	{ N_MSG_MNSTR_GILLMAN,
		"ޥ" },
	{ N_MSG_MNSTR_HARPY,
		"ϡԡ" },
	{ N_MSG_MNSTR_LAMIA,
		"ߥ" },
	{ N_MSG_MNSTR_MERMAN,
		"ޡޥ" },
	{ N_MSG_MNSTR_GNOLL,
		"Ρ" },
	{ N_MSG_MNSTR_SIREN,
		"졼" },
	{ N_MSG_MNSTR_SCYLLA,
		"" },
	{ N_MSG_MNSTR_LIZARDMAN,
		"ꥶɥޥ" },
	{ N_MSG_MNSTR_CAVEMAN,
		"ޥ" },
	{ N_MSG_MNSTR_GIANT,
		"㥤" },
	{ N_MSG_MNSTR_HUMBABA,
		"եХ" },
	{ N_MSG_MNSTR_TROLL,
		"ȥ" },
	{ N_MSG_MNSTR_YETI,
		"ƥ" },
	{ N_MSG_MNSTR_BEAR,
		"٥" },
	{ N_MSG_MNSTR_ROC,
		"å" },
	{ N_MSG_MNSTR_BAT,
		"Хå" },
	{ N_MSG_MNSTR_GREAT_CAT,
		"졼ȡå" },
	{ N_MSG_MNSTR_DOG,
		"ɥå" },
	{ N_MSG_MNSTR_HORSE,
		"ۡ" },
	{ N_MSG_MNSTR_WOLF,
		"" },
	{ N_MSG_MNSTR_BEHOLDER,
		"ӥۥ" },
	{ N_MSG_MNSTR_CERBERUS,
		"٥" },
	{ N_MSG_MNSTR_GRIFFON,
		"ե" },
	{ N_MSG_MNSTR_HYDRA,
		"ҥɥ" },
	{ N_MSG_MNSTR_HIPPOGRIFF,
		"ҥݥ" },
	{ N_MSG_MNSTR_BASILISK,
		"Хꥹ" },
	{ N_MSG_MNSTR_CHIMERA,
		"ޥ" },
	{ N_MSG_MNSTR_GORGON,
		"르" },
	{ N_MSG_MNSTR_HELLHOUND,
		"إ롦ϥ" },
	{ N_MSG_MNSTR_MANTICORE,
		"ޥƥ" },
	{ N_MSG_MNSTR_COCKATRICE,
		"ȥꥹ" },
	{ N_MSG_MNSTR_PEGASUS,
		"ڥ" },
	{ N_MSG_MNSTR_RUST_MONSTER,
		"饹ȡ󥹥" },
	{ N_MSG_MNSTR_UNICORN,
		"˥" },
	{ N_MSG_MNSTR_WYVERN,
		"磻С" },
	{ N_MSG_MNSTR_DOPPELGANGER,
		"ɥåڥ륲󥬡" },
	{ N_MSG_MNSTR_SUCCUBUS,
		"Х" },
	{ N_MSG_MNSTR_DURAHAN,
		"ǥϥ" },
	{ N_MSG_MNSTR_GREMLIN,
		"" },
	{ N_MSG_MNSTR_IMP,
		"" },
	{ N_MSG_MNSTR_MIND_FLAYER,
		"ޥɡե쥤䡼" },
	{ N_MSG_MNSTR_DWARF,
		"ɥ" },
	{ N_MSG_MNSTR_DRYAD,
		"ɥ饤" },
	{ N_MSG_MNSTR_ELF,
		"" },
	{ N_MSG_MNSTR_FAIRY,
		"ե꡼" },
	{ N_MSG_MNSTR_HALFLING,
		"ϡե" },
	{ N_MSG_MNSTR_LEPRECHAUN,
		"ץ饳" },
	{ N_MSG_MNSTR_PIXY,
		"ԥ" },
	{ N_MSG_MNSTR_GHOST,
		"" },
	{ N_MSG_MNSTR_POLTERGEIST,
		"ݥ륿" },
	{ N_MSG_MNSTR_SPIRIT,
		"ԥå" },
	{ N_MSG_MNSTR_WRAITH,
		"쥤" },
	{ N_MSG_MNSTR_OGRE,
		"" },
	{ N_MSG_MNSTR_GOBLIN,
		"֥" },
	{ N_MSG_MNSTR_HOBGOBLIN,
		"ۥ֥֥" },
	{ N_MSG_MNSTR_KOBOLD,
		"ܥ" },
	{ N_MSG_MNSTR_ORK,
		"" },
	{ N_MSG_MNSTR_GIANT_SPIDER,
		"㥤ȡѥ" },
	{ N_MSG_MNSTR_GIANT_ANT,
		"㥤ȡ" },
	{ N_MSG_MNSTR_GIANT_BEETLE,
		"㥤ȡӡȥ" },
	{ N_MSG_MNSTR_GIANT_CENTIPEDE,
		"㥤ȡƥԡ" },
	{ N_MSG_MNSTR_GIANT_SCORPION,
		"㥤ȡԥ" },
	{ N_MSG_MNSTR_WORM,
		"" },
	{ N_MSG_MNSTR_GOLEM,
		"" },
	{ N_MSG_MNSTR_GAS_CLOUD,
		"饦" },
	{ N_MSG_MNSTR_GARGOYLE,
		"" },
	{ N_MSG_MNSTR_HOMUNCULUS,
		"ۥ󥯥륹" },
	{ N_MSG_MNSTR_INVISIBLE_STALKER,
		"֥롦ȡ" },
	{ N_MSG_MNSTR_JACK_O_LANTERN,
		"å󥿥" },
	{ N_MSG_MNSTR_SLIME,
		"饤" },
	{ N_MSG_MNSTR_HAG,
		"ϥ" },
	{ N_MSG_MNSTR_DINOSAUR,
		"ʥ" },
	{ N_MSG_MNSTR_GIANT_LIZARD,
		"㥤ȡꥶ" },
	{ N_MSG_MNSTR_SNAKE,
		"͡" },
	{ N_MSG_MNSTR_MANDRAKE,
		"ޥɥ쥤" },
	{ N_MSG_MNSTR_PLANT_MONSTER,
		"ץȡ󥹥" },
	{ N_MSG_MNSTR_SPORE,
		"ݥ" },
	{ N_MSG_MNSTR_TREANT,
		"ȥ" },
	{ N_MSG_MNSTR_KRAKEN,
		"顼" },
	{ N_MSG_MNSTR_SEA_SERPENT,
		"ڥ" },
	{ N_MSG_MNSTR_GHOUL,
		"" },
	{ N_MSG_MNSTR_MUMMY,
		"ޥߡ" },
	{ N_MSG_MNSTR_SKELETON,
		"ȥ" },
	{ N_MSG_MNSTR_VAMPIRE,
		"ѥ" },
	{ N_MSG_MNSTR_WIGHT,
		"磻" },
	{ N_MSG_MNSTR_ZOMBIE,
		"" },
#endif

	{ N_MSG_MIMIC_FIND_MBR,
		"Ԥơ %s " },

/* trap */

	{ N_MSG_TRAP_SLEEP,
		"̲" },
	{ N_MSG_TRAP_ARW,
		"" },
	{ N_MSG_TRAP_POISON_DARTS,
		"ǥĤ" },
	{ N_MSG_TRAP_TELEPORT_PARTY,
		"ѡƥְִư" },
	{ N_MSG_TRAP_TELEPORT,
		"ְִư" },

	{ N_MSG_TRAPPED,
		"%s  %s ˤä" },
	{ N_MSG_NOT_TRAPPED,
		"%s 櫤ưʤä" },

/* spell begin */

	{ N_MSG_MAG,
		STR_MAG },
	{ N_MSG_SOR,
		STR_SOR },
	{ N_MSG_ENC,
		STR_ENC },
	{ N_MSG_SUM,
		STR_SUM },

	{ N_MSG_PRI,
		STR_PRI },
	{ N_MSG_SHA,
		STR_SHA },
	{ N_MSG_BAR,
		STR_BAR },
	{ N_MSG_NIN,
		STR_NIN },

	{ N_MSG_MAG_MISC,
		STR_MAG " - " },
	{ N_MSG_MAG_DETECT,
		STR_MAG " - õ" },
	{ N_MSG_MAG_CHANGE_STAT,
		STR_MAG " - ƥѲ" },
	{ N_MSG_SOR_ATTACK,
		STR_SOR " - " },
	{ N_MSG_SOR_DEFENSE,
		STR_SOR " - ɸ" },
	{ N_MSG_SOR_WEAKEN_STAT,
		STR_SOR " - ơ۾" },
	{ N_MSG_ENC_STRENGTHEN_ABILITY,
		STR_ENC " - ӥƥ" },
	{ N_MSG_ENC_STRENGTHEN_MISC,
		STR_ENC " - " },
	{ N_MSG_ENC_WEAKEN_ABILITY,
		STR_ENC " - ӥƥ" },
	{ N_MSG_ENC_WEAKEN_MISC,
		STR_ENC " - " },
	{ N_MSG_SUM_SUMMON,
		STR_SUM " - " },
	{ N_MSG_PRI_CURE,
		STR_PRI " - " },
	{ N_MSG_PRI_CURE_STAT,
		STR_PRI " - ֲ" },
	{ N_MSG_PRI_RESIST,
		STR_PRI " - " },
	{ N_MSG_PRI_HOLY,
		STR_PRI " - " },
	{ N_MSG_NIN_DISASTER,
		STR_NIN " - ŷϰ" },
	{ N_MSG_NIN_MISC,
		STR_NIN " - " },

	{ N_MSG_ERR_SPELL,
		"%s ϼʸФƤʤ" },
	{ N_MSG_SPELL_NO_LEARN,
		"̵" },

/* [ˡ] */

/*  */

	{ N_MSG_SPELL_LIGHT,
		"" },
	{ N_MSG_SPELL_DARKNESS,
		"Ű" },
	{ N_MSG_SPELL_KNOCK,
		"" },
	{ N_MSG_SPELL_LOCK,
		"ܾ" },
	{ N_MSG_SPELL_DISARM_TRAP,
		"櫲" },
	{ N_MSG_SPELL_DISPEL_MAGIC,
		"ˡ" },
	{ N_MSG_SPELL_TELEPORT_PARTY,
		"ѡƥְִư" },
	{ N_MSG_SPELL_TELEPORT,
		"ְִư" },
	{ N_MSG_SPELL_RECALL,
		"" },
	{ N_MSG_SPELL_MIRROR_IMAGE,
		"" },
	{ N_MSG_SPELL_ANIMATE_OBJECTS,
		"ʪ" },
	{ N_MSG_SPELL_SHELTER,
		"륿" },
	{ N_MSG_SPELL_CREATE_FOOD,
		"" },
	{ N_MSG_SPELL_CREATE_UNDEAD,
		"ǥå¤" },

/* õΡ */

	{ N_MSG_SPELL_IDENTIFY_ITEM,
		"" },
	{ N_MSG_SPELL_SEARCHING,
		"õ" },
	{ N_MSG_SPELL_ANALYZE_DWEOMER,
		"ʬ" },
	{ N_MSG_SPELL_DETECT_DOORS,
		"õ" },
	{ N_MSG_SPELL_DETECT_ITEM,
		"ƥõ" },
	{ N_MSG_SPELL_DETECT_MAGIC,
		"ˡ" },
	{ N_MSG_SPELL_DETECT_MONSTER,
		"󥹥" },
	{ N_MSG_SPELL_DETECT_TRAPS,
		"õ" },
	{ N_MSG_SPELL_SENSE_INVISIBLE,
		"ԲĻ봶" },

/* Ѳ_ƥ */

	{ N_MSG_SPELL_FLY,
		"ͷ" },
	{ N_MSG_SPELL_FEATHER_FALL,
		"Φ" },
	{ N_MSG_SPELL_VANISH,
		"ԲĻ" },
	{ N_MSG_SPELL_DARKVISION,
		"Ż" },
	{ N_MSG_SPELL_PASSWALL,
		"ȴ" },

/* Ѳ_üե饰 */

	{ N_MSG_SPELL_POLYMORPH_OTHER,
		"¾ѿ" },
	{ N_MSG_SPELL_POLYMORPH_SELF,
		"ѿ" },
	{ N_MSG_SPELL_STEALTH,
		"̩" },

/* [Ʈˡ] */

/*  */

	{ N_MSG_SPELL_MAGIC_MISSILE,
		"ˡΥߥ" },
	{ N_MSG_SPELL_FIRE_BALL,
		"Фε" },
	{ N_MSG_SPELL_ICE_BLIZZARD,
		"ɹο" },
	{ N_MSG_SPELL_MIND_STORM,
		"" },
	{ N_MSG_SPELL_ACID_RAIN,
		"α" },
	{ N_MSG_SPELL_LIGHTNING_BOLT,
		"ŷ" },
	{ N_MSG_SPELL_POISON_CLOUD,
		"Ǥα" },
	{ N_MSG_SPELL_DEATH_SPELL,
		"μ" },

/* ɸ */

	{ N_MSG_SPELL_MAGE_ARMOR,
		"ˡγ" },
	{ N_MSG_SPELL_MAGIC_SHIELD,
		"ˡν" },
	{ N_MSG_SPELL_STONESKIN,
		"Ф" },
	{ N_MSG_SPELL_IRON_BODY,
		"Ŵ" },
	{ N_MSG_SPELL_SPELL_RESISTANCE,
		"ʸ" },
	{ N_MSG_SPELL_COUNTER_MAGIC,
		"ʸȿ" },

/* _ƥ */

	{ N_MSG_SPELL_STONE,
		"в" },
	{ N_MSG_SPELL_PARALYZE,
		"" },
	{ N_MSG_SPELL_POISON,
		"" },
	{ N_MSG_SPELL_CONFUSION,
		"" },
	{ N_MSG_SPELL_BLINDNESS,
		"" },
	{ N_MSG_SPELL_SLEEP,
		"̲" },
	{ N_MSG_SPELL_SILENCE,
		"" },
	{ N_MSG_SPELL_FEAR,
		"" },
	{ N_MSG_SPELL_HALLUCINATION,
		"" },
	{ N_MSG_SPELL_CHARM,
		"̥λ" },

/* [ˡ] */

/* _٥ */

	{ N_MSG_SPELL_SHARPNESS,
		"" },
	{ N_MSG_SPELL_STRENGTH,
		"" },
	{ N_MSG_SPELL_QUICKNESS,
		"Ҿ" },
	{ N_MSG_SPELL_WISE,
		"Ƚ" },
	{ N_MSG_SPELL_BRAINY,
		"" },
	{ N_MSG_SPELL_ATTRACTIVE,
		"̥" },

/* _ */

	{ N_MSG_SPELL_POWER_UP_HP,
		"" },

/* _üե饰 */

	{ N_MSG_SPELL_HASTE,
		"®" },

/* _٥ */

	{ N_MSG_SPELL_DULLNESS,
		"ٸ" },
	{ N_MSG_SPELL_WEAKNESS,
		"ٸ" },
	{ N_MSG_SPELL_SLOWNESS,
		"Ҿٸ" },
	{ N_MSG_SPELL_FOOLISH,
		"Ƚϸ" },
	{ N_MSG_SPELL_BRAINLESS,
		"ϸ" },
	{ N_MSG_SPELL_UNATTRACTIVE,
		"̥ϸ" },

/* _и */

	{ N_MSG_SPELL_ENERGY_DRAIN,
		"̿ϵۼ" },

/* _üե饰 */

	{ N_MSG_SPELL_SLOW,
		"®" },
	{ N_MSG_SPELL_HUNGER,
		"" },
	{ N_MSG_SPELL_CANCELLATION,
		"üǽ" },

/* [ˡ] */

/* */
	{ N_MSG_SPELL_SUMMON_MONSTER,
		"ʪ" },
	{ N_MSG_SPELL_DISMISSAL,
		"" },

/* [] */

/* Ͳ */

	{ N_MSG_SPELL_CURE_HP_LIGHT,
		"Ͼ" },
	{ N_MSG_SPELL_CURE_HP_MODERATE,
		"" },
	{ N_MSG_SPELL_CURE_HP_SERIOUS,
		"" },
	{ N_MSG_SPELL_CURE_HP_MAX,
		"" },
	{ N_MSG_SPELL_CURE_MP,
		"ϲ" },
	{ N_MSG_SPELL_TRANSFER_MP,
		"ž" },
	{ N_MSG_SPELL_REGENERATION,
		"" },
	{ N_MSG_SPELL_RESTORE_EXPERIENCE,
		"иͲ" },
	{ N_MSG_SPELL_RESURRECTION,
		"" },
	{ N_MSG_SPELL_HEAL,
		"" },

/* ֲ */

	{ N_MSG_SPELL_CURE_STATUS,
		"ֲ" },

	{ N_MSG_SPELL_CURE_STONE,
		"в" },
	{ N_MSG_SPELL_CURE_PARALYZE,
		"" },
	{ N_MSG_SPELL_CURE_BLINDNESS,
		"ܲ" },
	{ N_MSG_SPELL_CURE_POISON,
		"ǲ" },
	{ N_MSG_SPELL_CURE_CONFUSION,
		"" },
	{ N_MSG_SPELL_CURE_SILENCE,
		"۲" },
	{ N_MSG_SPELL_CURE_SLEEP,
		"̲" },
	{ N_MSG_SPELL_CURE_FEAR,
		"ݲ" },
	{ N_MSG_SPELL_CURE_HALLUCINATION,
		"в" },
	{ N_MSG_SPELL_CURE_CHARM,
		"̥λ" },

	{ N_MSG_SPELL_REMOVE_CURSE,
		"" },

/*  */

	{ N_MSG_SPELL_PROTECTION,
		"ɸ" },
	{ N_MSG_SPELL_RESIST_PHYSICAL,
		"ʪ" },
	{ N_MSG_SPELL_RESIST_HEAT,
		"Ǯ" },
	{ N_MSG_SPELL_RESIST_COLD,
		"" },
	{ N_MSG_SPELL_RESIST_WIND,
		"" },
	{ N_MSG_SPELL_RESIST_ACID,
		"ڻ" },
	{ N_MSG_SPELL_RESIST_ELECTRICITY,
		"" },
	{ N_MSG_SPELL_RESIST_POISON,
		"" },

/*  */

	{ N_MSG_SPELL_BLESS,
		"ʡ" },
	{ N_MSG_SPELL_DISPEL_UNDEAD,
		"ǥå໶" },
	{ N_MSG_SPELL_SANCTUARY,
		"" },
	{ N_MSG_SPELL_WISH,
		"˾" },

/* [Ǧ] */

/* ŷϰ */

#if	0
@@@
	{ N_MSG_SPELL_,
		"ۤν()" },
#endif
	{ N_MSG_SPELL_CONFLAGRATION,
		"ۤν(к)" },
	{ N_MSG_SPELL_EARTHQUAKE,
		"ۤν(Ͽ)" },
	{ N_MSG_SPELL_THUNDERCLOUD,
		"ۤν()" },
	{ N_MSG_SPELL_INUNDATION,
		"ۤν()" },

#if	0
@@@
/*  */

	{ N_MSG_SPELL_,
		"ۤν(Ф)" },
	{ N_MSG_SPELL_,
		"ۤν(оä)" },
	{ N_MSG_SPELL_,
		"ۤν()" },
	{ N_MSG_SPELL_,
		"ۤν()" },
	{ N_MSG_SPELL_,
		"ۤν(Ϥ)" },
#endif

/*  */

	{ N_MSG_SPELL_SUBSTITUTE,
		"ۤν()" },
	{ N_MSG_SPELL_BURNING_HANDS,
		"ۤν()" },
#if	0
@@@
	{ N_MSG_SPELL_,
		"ۤν()" },
	{ N_MSG_SPELL_,
		"ۤν()" },
	{ N_MSG_SPELL_,
		"ۤν()" },
#endif

/* ANC */

	{ N_MSG_SPELL_NOTHING,
		"̵" },

/* spell end */

/* color begin */

	{ N_MSG_ATTR_NORMAL,
		"̾ο" },
	{ N_MSG_ATTR_ERR,
		"顼ο" },
	{ N_MSG_ATTR_MENU_DIS,
		"̵ʥ˥塼ܤο" },
	{ N_MSG_ATTR_MENU_SEL,
		"˥塼ܤο" },
	{ N_MSG_ATTR_MAP_ITEM,
		"ƥο" },
	{ N_MSG_ATTR_MAP_SQUARE,
		STR_SQUARE "ο" },
	{ N_MSG_ATTR_MAP_MNSTR,
		"󥹥ο" },
	{ N_MSG_ATTR_MAP_CRSR,
		"ο" },
	{ N_MSG_ATTR_FX_MBR_PLUS,
		"Сβο" },
	{ N_MSG_ATTR_FX_MBR_MINUS,
		"СؤΥ᡼ο" },
	{ N_MSG_ATTR_FX_MBR_CRTCL,
		"СؤΥƥο" },
	{ N_MSG_ATTR_FX_MNSTR_PLUS,
		"󥹥βο" },
	{ N_MSG_ATTR_FX_MNSTR_MINUS,
		"󥹥ؤΥ᡼ο" },
	{ N_MSG_ATTR_FX_MNSTR_CRTCL,
		"󥹥ؤΥƥο" },
	{ N_MSG_ATTR_VFX,
		"եȤο" },
	{ N_MSG_ATTR_MBR_1,
		"Сο 1" },
	{ N_MSG_ATTR_MBR_2,
		"Сο 2" },
	{ N_MSG_ATTR_MBR_3,
		"Сο 3" },
	{ N_MSG_ATTR_MBR_4,
		"Сο 4" },
	{ N_MSG_ATTR_MBR_5,
		"Сο 5" },
	{ N_MSG_ATTR_MBR_6,
		"Сο 6" },

/* color end */

/* menu begin */

	{ N_MSG_MENU_FRAME,
		"----------------------------------------"
		"----------------------------------------" },
	{ N_MSG_MENU_CLR_FMT,
		"% *s" },
	{ N_MSG_MENU_SELECT_FMT,
		"*%s%s%-*s%*s%*s*" },
	{ N_MSG_MENU_NOT_SELECT_FMT,
		" %s%s%-*s%*s%*s " },
	{ N_MSG_MENU_CONTENTS_FMT,
		"%s%*s" },
	{ N_MSG_MENU_FLG_LS_CHK_ON,
		"[*]" },
	{ N_MSG_MENU_FLG_LS_CHK_OFF,
		"[ ]" },
	{ N_MSG_MENU_FLG_LS_CHK_NULL,
		"   " },
	{ N_MSG_MENU_ACCEL_KEY_FMT,
		"(%s)" },
	{ N_MSG_MENU_DIRECT_FMT,
		"%c)" },
	{ N_MSG_MENU_H_LINE,
		"-" },
	{ N_MSG_MENU_V_LINE,
		"|" },
	{ N_MSG_MENU_LEFT,
		"+---" },
	{ N_MSG_MENU_LEFT_PREV,
		"+<<=" },
	{ N_MSG_MENU_RIGHT,
		"---+" },
	{ N_MSG_MENU_RIGHT_NEXT,
		"=>>+" },
	{ N_MSG_MENU_CORNER,
		"+" },
	{ N_MSG_MENU_KIND_BRANCH,
		" >" },
	{ N_MSG_MENU_KIND_OPEN_WIN_ITEM,
		"..." },
	{ N_MSG_MENU_KIND_ITEM,
		"" },

	{ N_MSG_MENU_YES,
		"Ϥ" },
	{ N_MSG_MENU_NO,
		"" },

	{ N_MSG_MENU_MIN,
		"[min]" },
	{ N_MSG_MENU_MAX,
		"[max]" },
	{ N_MSG_MENU_OK,
		"[ok]" },

	{ N_MSG_MENU_DUP_ACCEL_KEY,
		"졼νʣ: '%s' (%s)" },

	{ N_MSG_TTL_MENU_MAIN_RACE,
		"²" },
	{ N_MSG_TTL_MENU_SUB_RACE,
		"ݤ碌" },
	{ N_MSG_TTL_MENU_SEX,
		"" },
	{ N_MSG_TTL_MENU_CLASS,
		"饹" },

/* main menu */

	{ N_MSG_MENU_EXEC,
		"¹" },
	{ N_MSG_MENU_MARK,
		"ޡ" },
	{ N_MSG_MENU_MOVE,
		"ư" },
	{ N_MSG_MENU_SPELL,
		"ʸ" },
	{ N_MSG_MENU_FIGHT,
		"Ʈ" },
	{ N_MSG_MENU_ITEM,
		"ƥ" },
	{ N_MSG_MENU_EQUIP,
		"" },
	{ N_MSG_MENU_MISC,
		"¾" },

/* menu mark begin */

	{ N_MSG_MENU_POINT_CRSR,
		"ޡΤǲ" },

	{ N_MSG_MENU_SEL_OBJ_MBR,
		"С" },
	{ N_MSG_MENU_SEL_OBJ_SQUARE,
		STR_SQUARE },
	{ N_MSG_MENU_SEL_OBJ_ITEM,
		"ƥ" },
	{ N_MSG_MENU_SEL_OBJ_MNSTR,
		"󥹥" },
	{ N_MSG_MENU_SEL_OBJ_DOOR,
		"ɥ" },
	{ N_MSG_MENU_SEL_OBJ_TRAP,
		"ȥå" },
	{ N_MSG_MENU_SEL_OBJ_POS,
		"ֻ" },
	{ N_MSG_MENU_SEL_OBJ_CLEAR,
		"ޡ" },
	{ N_MSG_MENU_SEL_OBJ_AUTO,
		"ưޡ" },

	{ N_MSG_MENU_DIST_NEAR,
		"" },
	{ N_MSG_MENU_DIST_MEDIUM,
		"" },
	{ N_MSG_MENU_DIST_FAR,
		"" },

	{ N_MSG_MENU_MARK_FIGHT,
		"臘" },
	{ N_MSG_MENU_MARK_THROW,
		"ꤲ" },
	{ N_MSG_MENU_MARK_TAIL,
		"ɤ" },

	{ N_MSG_MENU_MARK_ITEM_PICK_UP,
		"Ҥ" },
	{ N_MSG_MENU_MARK_ITEM_OPEN,
		"" },
	{ N_MSG_MENU_MARK_ITEM_DISARM,
		STR_DISARM "" },
	{ N_MSG_MENU_MARK_ITEM_BREAK,
		"" },
	{ N_MSG_MENU_MARK_ITEM_SRCH,
		"Ĵ٤" },

	{ N_MSG_MENU_MARK_DOOR_OPEN,
		"" },
	{ N_MSG_MENU_MARK_DOOR_CLOSE,
		"Ĥ" },
	{ N_MSG_MENU_MARK_DOOR_JAM,
		"ꤹ" },
	{ N_MSG_MENU_MARK_DOOR_DISARM,
		STR_DISARM "" },
	{ N_MSG_MENU_MARK_DOOR_BREAK,
		"" },
	{ N_MSG_MENU_MARK_DOOR_PEEP,
		"" },
	{ N_MSG_MENU_MARK_DOOR_SRCH,
		"Ĵ٤" },

	{ N_MSG_MENU_MARK_TRAP_DISARM,
		STR_DISARM "" },
	{ N_MSG_MENU_MARK_TRAP_BREAK,
		"" },
	{ N_MSG_MENU_MARK_TRAP_SRCH,
		"Ĵ٤" },

	{ N_MSG_MENU_MARK_SQUARE_POS,
		"ꤷƲ" },

/* menu mark end */

/* menu select item begin */

	{ N_MSG_MENU_ITEM_LS_EQUIP,
		"" },

	{ N_MSG_MENU_ITEM_QUAFF,
		"" },
	{ N_MSG_MENU_ITEM_READ,
		"ɤ" },
	{ N_MSG_MENU_ITEM_ZAP,
		"" },
	{ N_MSG_MENU_ITEM_EAT,
		"٤" },
	{ N_MSG_MENU_ITEM_SMOKE,
		"" },
	{ N_MSG_MENU_ITEM_FILL_LAMP,
		"פ" },
	{ N_MSG_MENU_ITEM_EQUIP,
		"" },
	{ N_MSG_MENU_ITEM_READY_THROW,
		"ꤲѰ" },
	{ N_MSG_MENU_ITEM_SEND,
		"Ϥ" },
	{ N_MSG_TTL_MENU_ITEM_SEND,
		"ïϤ?" },
	{ N_MSG_MENU_ITEM_DROP,
		"Ȥ" },
	{ N_MSG_MENU_ITEM_SRCH,
		"Ĵ٤" },

	{ N_MSG_MENU_ITEM_RECEIVE,
		"餦" },

/* menu select item end */

/* menu select equipment begin */

	{ N_MSG_MENU_SEL_EQUIP_WIELDING,
		STR_EQUIP_WIELDING },
	{ N_MSG_MENU_SEL_EQUIP_SHIELD,
		STR_EQUIP_SHIELD },
	{ N_MSG_MENU_SEL_EQUIP_BOW,
		STR_EQUIP_BOW },
	{ N_MSG_MENU_SEL_EQUIP_ARW,
		STR_EQUIP_ARW },
	{ N_MSG_MENU_SEL_EQUIP_HEAD,
		STR_EQUIP_HEAD },
	{ N_MSG_MENU_SEL_EQUIP_NECK,
		STR_EQUIP_NECK },
	{ N_MSG_MENU_SEL_EQUIP_BODY,
		STR_EQUIP_BODY },
	{ N_MSG_MENU_SEL_EQUIP_ARM,
		STR_EQUIP_ARM },
	{ N_MSG_MENU_SEL_EQUIP_RIGHT_HAND,
		STR_EQUIP_RIGHT_HAND },
	{ N_MSG_MENU_SEL_EQUIP_LEFT_HAND,
		STR_EQUIP_LEFT_HAND },
	{ N_MSG_MENU_SEL_EQUIP_FEET,
		STR_EQUIP_FEET },
	{ N_MSG_MENU_SEL_EQUIP_ABOUT_BODY,
		STR_EQUIP_ABOUT_BODY },
	{ N_MSG_MENU_SEL_EQUIP_LIGHT_SOURCE,
		STR_EQUIP_LIGHT_SOURCE },
	{ N_MSG_MENU_EQUIP_LS_ITEM,
		"ƥ" },

	{ N_MSG_MENU_EQUIP_WEAR,
		"" },
	{ N_MSG_MENU_EQUIP_TAKE_OFF,
		"" },

	{ N_MSG_MENU_EQUIP_WEAR_MBR,
		"" },
	{ N_MSG_MENU_EQUIP_TAKE_OFF_MBR,
		"" },

/* menu select equipment end */

/* menu misc begin */

	{ N_MSG_MENU_STAIRS,
		"" },
	{ N_MSG_MENU_SRCH,
		"Ĵ٤" },
	{ N_MSG_MENU_DATA,
		"ǽ" },
	{ N_MSG_MENU_MNSTR_DATA,
		"󥹥Ĵ٤" },
	{ N_MSG_MENU_SLEEP,
		"̲" },
	{ N_MSG_MENU_COLLECT_GOLD,
		"򽸤" },
	{ N_MSG_MENU_DIVIDE_GOLD,
		"ʬۤ" },
	{ N_MSG_MENU_MSG,
		"å" },
	{ N_MSG_MENU_OUT_MAP_FILE,
		"ޥåפΥե" },
	{ N_MSG_MENU_SHELL,
		"" },
	{ N_MSG_MENU_CNF,
		"" },
	{ N_MSG_MENU_WIZARD,
		"" },
	{ N_MSG_MENU_ABOUT_GAME,
		STR_FILE_NAME_GAME " ˤĤ" },
	{ N_MSG_MENU_EXIT,
		"λ" },

	{ N_MSG_MENU_STAIRS_UP,
		"" },
	{ N_MSG_MENU_STAIRS_DOWN,
		"" },

	{ N_MSG_TTL_MENU_SRCH,
		"Ĵ٤" },
	{ N_MSG_MENU_SRCH_EXEC,
		"¹" },
	{ N_MSG_MENU_SRCH_EXEC_ALL,
		"¹()" },
	{ N_MSG_MENU_SRCH_CANCEL_ALL,
		"()" },
	{ N_MSG_MENU_SRCH_AUTO_OFF,
		"ư" },

	{ N_MSG_MNSTR_DATA_NAME,
		"%c%c  %s " },
	{ N_MSG_MNSTR_DATA_MAX_LEV,
		"%c%c κǹ٥ %ld " },
	{ N_MSG_MNSTR_DATA_MIN_LEV,
		"%c%c κ٥ %ld " },

/* menu cursor begin */

	{ N_MSG_MENU_CRSR,
		"" },

/* menu cursor move begin */

	{ N_MSG_MENU_CRSR_MOVE,
		"ư" },
	{ N_MSG_MENU_CRSR_MOVE_UP,
		"" },
	{ N_MSG_MENU_CRSR_MOVE_DOWN,
		"" },
	{ N_MSG_MENU_CRSR_MOVE_LEFT,
		"" },
	{ N_MSG_MENU_CRSR_MOVE_RIGHT,
		"" },
	{ N_MSG_MENU_CRSR_MOVE_UP_LEFT,
		"" },
	{ N_MSG_MENU_CRSR_MOVE_UP_RIGHT,
		"" },
	{ N_MSG_MENU_CRSR_MOVE_DOWN_LEFT,
		"" },
	{ N_MSG_MENU_CRSR_MOVE_DOWN_RIGHT,
		"" },

/* menu cursor move end */

/* menu cursor quick move begin */

	{ N_MSG_MENU_CRSR_QUICK_MOVE,
		"٤ޤǰư" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_UP,
		"" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_DOWN,
		"" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_LEFT,
		"" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_RIGHT,
		"" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_UP_LEFT,
		"" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_UP_RIGHT,
		"" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_DOWN_LEFT,
		"" },
	{ N_MSG_MENU_CRSR_QUICK_MOVE_DOWN_RIGHT,
		"" },

/* menu cursor quick move end */

	{ N_MSG_MENU_CRSR_SCROLL_CENTER,
		"󥿥" },
	{ N_MSG_MENU_CRSR_NEXT_POS_MBR,
		"ΥС" },
	{ N_MSG_MENU_CRSR_NEXT_POS_MNSTR,
		"Υ󥹥" },
	{ N_MSG_MENU_CRSR_NEXT_POS_ITEM,
		"Υƥ" },
	{ N_MSG_MENU_CRSR_NEXT_POS_DOOR,
		"Υɥ" },
	{ N_MSG_MENU_CRSR_NEXT_POS_OBJ,
		"ʪ" },
	{ N_MSG_MENU_CRSR_NEXT_POS_SQUARE,
		STR_SQUARE },
	{ N_MSG_MENU_CRSR_NEXT_POS_ALL,
		"" },
	{ N_MSG_MENU_CRSR_PREV_POS,
		"" },

/* menu cursor end */

/* menu config begin */

	{ N_MSG_MENU_AUTO_FIGHT,
		"󥹥ˤ֤Ĥä鹶⤹" },
	{ N_MSG_MENU_AUTO_DOOR,
		"ɥưŪ˳" },
	{ N_MSG_MENU_AVOID_TRAP,
		"櫤򤱤" },
	{ N_MSG_MENU_AUTO_RELOAD,
		"ưŶ" },
	{ N_MSG_MENU_SCROLL_PAGE,
		"ڡ" },
	{ N_MSG_MENU_SCROLL_SMOOTH,
		"ࡼ" },
	{ N_MSG_MENU_SCROLL_CENTER,
		"ࡼ(濴)" },
	{ N_MSG_MENU_MUL_MSG_LINE,
		"åԤʣ" },
	{ N_MSG_MENU_VFX,
		"и" },
	{ N_MSG_MENU_COLOR,
		"ɽ" },
	{ N_MSG_MENU_CRSR_PTN,
		"η" },

	{ N_MSG_MENU_VFX_MBR_HP_ADD,
		"СHPβ" },
	{ N_MSG_MENU_VFX_MBR_HP_SUB,
		"СHPΥ᡼" },
	{ N_MSG_MENU_VFX_MBR_HP_SUB_CRTCL,
		"СHPΥƥ롦᡼" },
	{ N_MSG_MENU_VFX_MBR_ARW,
		"Сƻ" },
	{ N_MSG_MENU_VFX_MNSTR_HP_ADD,
		"󥹥HPβ" },
	{ N_MSG_MENU_VFX_MNSTR_HP_SUB,
		"󥹥HPΥ᡼" },
	{ N_MSG_MENU_VFX_MNSTR_HP_SUB_CRTCL,
		"󥹥HPΥƥ롦᡼" },
	{ N_MSG_MENU_VFX_MNSTR_ARW,
		"󥹥ƻ" },
	{ N_MSG_MENU_VFX_WAIT,
		"[%ld]" },

	{ N_MSG_MENU_FG,
		"ʿ" },
	{ N_MSG_MENU_BG,
		"طʿ" },
	{ N_MSG_MENU_COLOR_BLACK,
		"" },
	{ N_MSG_MENU_COLOR_RED,
		"" },
	{ N_MSG_MENU_COLOR_GREEN,
		"" },
	{ N_MSG_MENU_COLOR_YELLOW,
		"" },
	{ N_MSG_MENU_COLOR_BLUE,
		"" },
	{ N_MSG_MENU_COLOR_MAGENTA,
		"" },
	{ N_MSG_MENU_COLOR_CYAN,
		"忧" },
	{ N_MSG_MENU_COLOR_WHITE,
		"" },

	{ N_MSG_MENU_ATTR,
		"°" },
	{ N_MSG_MENU_UNDERLINE,
		"" },
	{ N_MSG_MENU_REVERSE,
		"ȿž" },
	{ N_MSG_MENU_BLINK,
		"" },
	{ N_MSG_MENU_BOLD,
		"Ĵ" },

	{ N_MSG_MENU_CRSR_PTN_SEL,
		"ֹϤƲ" },

/* menu config end */

	{ N_MSG_TTL_MENU_EXIT,
		"֤˽λޤ?" },

/* menu wizard begin */

	{ N_MSG_TTL_MENU_WIZARD,
		"" },
	{ N_MSG_MENU_WIZARD_ON_LIGHT,
		"" },
	{ N_MSG_MENU_WIZARD_OFF_LIGHT,
		"ä" },

/* menu wizard end */

/* menu misc end */

/* menu auto mark begin */

	{ N_MSG_MENU_AUTO_MARK_TITLE,
		"ưޡ" },
	{ N_MSG_MENU_AUTO_MARK_EXEC,
		"¹" },
	{ N_MSG_MENU_AUTO_MARK_EDIT,
		"Խ" },
	{ N_MSG_MENU_AUTO_MARK_ARRANGE,
		"Ƭ¤ٴ" },
	{ N_MSG_MENU_AUTO_MARK_INVALID,
		"----" },

	{ N_MSG_TTL_MENU_AUTO_MARK_EDIT,
		"(%s) - %s" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_TRGT,
		"о   : %s" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_DIST,
		"ֹ礤 : %s" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_ACT,
		"ư   : %s" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_COND,
		"   : %s" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_APPOINT_ITEM,
		"ƥ" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_CONT,
		"Ϣ³ޡ" },
	{ N_MSG_MENU_AUTO_MARK_EDIT_PRIORITY,
		"ߤͥ" },

	{ N_MSG_TTL_MENU_AUTO_MARK_TRGT,
		"о(%s) - %s" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_MNSTR,
		"󥹥" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_ITEM,
		"ƥ" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_DOOR,
		"ɥ" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_TRAP,
		"ȥå" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_MBR,
		"С" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_UNCHANGE,
		"ѹʤ" },
	{ N_MSG_MENU_AUTO_MARK_TRGT_CLEAR,
		"ޡ" },

	{ N_MSG_TTL_MENU_AUTO_MARK_DIST,
		"ֹ礤(%s) - %s" },
	{ N_MSG_MENU_AUTO_MARK_DIST_NEAR,
		"" },
	{ N_MSG_MENU_AUTO_MARK_DIST_MEDIUM,
		"" },
	{ N_MSG_MENU_AUTO_MARK_DIST_FAR,
		"Υ" },

	{ N_MSG_TTL_MENU_AUTO_MARK_ACT,
		"ư(%s) - %s" },
	{ N_MSG_MENU_AUTO_MARK_ACT_FIGHT,
		"臘" },
	{ N_MSG_MENU_AUTO_MARK_ACT_THROW,
		"ꤲ" },
	{ N_MSG_MENU_AUTO_MARK_ACT_TAIL,
		"ɤ" },
	{ N_MSG_MENU_AUTO_MARK_ACT_SRCH,
		"Ĵ٤" },
	{ N_MSG_MENU_AUTO_MARK_ACT_PICK_UP,
		"Ҥ" },
	{ N_MSG_MENU_AUTO_MARK_ACT_BREAK,
		"" },
	{ N_MSG_MENU_AUTO_MARK_ACT_OPEN,
		"" },
	{ N_MSG_MENU_AUTO_MARK_ACT_CLOSE,
		"Ĥ" },
	{ N_MSG_MENU_AUTO_MARK_ACT_JAM,
		"ꤹ" },
	{ N_MSG_MENU_AUTO_MARK_ACT_DISARM,
		STR_DISARM "" },
	{ N_MSG_MENU_AUTO_MARK_ACT_PEEP,
		"Τ" },

	{ N_MSG_TTL_MENU_AUTO_MARK_COND,
		"(%s) - %s" },
	{ N_MSG_MENU_AUTO_MARK_COND_NEAREST,
		"ֶᤤ" },
	{ N_MSG_MENU_AUTO_MARK_COND_DISPERSE,
		"Ф餱" },
	{ N_MSG_MENU_AUTO_MARK_COND_STAGGER,
		"Ƥ" },
	{ N_MSG_MENU_AUTO_MARK_COND_OWN,
		"äƤ" },

	{ N_MSG_TTL_MENU_AUTO_MARK_APPOINT_ITEM_MJR,
		"ƥ(%s) - %s" },
	{ N_MSG_TTL_MENU_AUTO_MARK_APPOINT_ITEM_MNR,
		"ƥܺ(%s) - %s" },

	{ N_MSG_NAME_DFLT_AUTO_MARK_FIGHT,
		"Ʈ" },
	{ N_MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
		"Ʈ()" },
	{ N_MSG_NAME_DFLT_AUTO_MARK_ITEM_ALL,
		"ƤΥƥ" },
	{ N_MSG_NAME_DFLT_AUTO_MARK_ITEM_OWN,
		"äƤ륢ƥ" },
	{ N_MSG_NAME_DFLT_AUTO_MARK_CLEAR,
		"" },

/* menu auto mark end */

/* menu town begin */

	{ N_MSG_MENU_SHOP_SEL_MBR,
		"%s ï?" },

	{ N_MSG_BUY,
		"㤦" },
	{ N_MSG_SALE_ITEM,
		"ƥ" },
	{ N_MSG_SALE_EQUIP,
		"" },

	{ N_MSG_CAN_USE_ITEM_YES,
		"o: " },
	{ N_MSG_CAN_USE_ITEM_REST,
		" : " },
	{ N_MSG_CAN_USE_ITEM_NO,
		"x: " },
	{ N_MSG_CAN_USE_ITEM_ERR,
		"?: " },

	{ N_MSG_MENU_BUY,
		"%s 㤤ޤ?" },
	{ N_MSG_MENU_SALE,
		"%s ޤ?" },
	{ N_MSG_TTL_MENU_BUY,
		"㤤ޤ?" },
	{ N_MSG_TTL_MENU_SALE,
		"ޤ?" },
	{ N_MSG_MENU_REACHED_BUY,
		"%s 㤤ޤ" },
	{ N_MSG_MENU_REACHED_SALE,
		"%s ޤ" },

	{ N_MSG_FMT_MENU_SHOP,
		"%s %s %s %ld " STR_GOLD },
	{ N_MSG_MENU_SHOP_DATA,
		"ǽ" },
	{ N_MSG_MENU_SHOP_COLLECT_GOLD,
		"򽸤" },
	{ N_MSG_MENU_SHOP_DIVIDE_GOLD,
		"ʬۤ" },
	{ N_MSG_MENU_SHOP_BUY,
		"㤦" },
	{ N_MSG_MENU_SHOP_SALE_ITEM,
		"ʪ" },
	{ N_MSG_MENU_SHOP_SALE_EQUIP,
		"" },

	{ N_MSG_TTL_MENU_TEMPLE,
		"%s %s %ld " STR_GOLD },
	{ N_MSG_FMT_MENU_TEMPLE,
		"%-*s %4ld " STR_GOLD },
	{ N_MSG_MENU_TEMPLE_REMOVE_CURSE,
		"" },
	{ N_MSG_MENU_TEMPLE_CURE_STATUS,
		"ֲ" },
	{ N_MSG_MENU_TEMPLE_RESURRECTION,
		"" },
	{ N_MSG_MENU_TEMPLE_CONTRIBUTION,
		"" },

	{ N_MSG_TTL_MENU_TEMPLE_REMOVE_CURSE,
		"ޤ?" },
	{ N_MSG_TTL_MENU_TEMPLE_CURE_STATUS,
		"ֲޤ?" },
	{ N_MSG_TTL_MENU_TEMPLE_RESURRECTION,
		"ޤ?" },
	{ N_MSG_TTL_MENU_TEMPLE_CONTRIBUTION,
		"դޤ?" },

	{ N_MSG_MENU_REMOVE_CURSE,
		"%s μϲ򤱤" },
	{ N_MSG_MENU_REMOVE_CURSE_ERR,
		"%s ϼƤޤ" },
	{ N_MSG_MENU_CURE_STATUS,
		"%s ξ֤ϲ" },
	{ N_MSG_MENU_CURE_STATUS_ERR,
		"%s ξ֤ϰޤ" },
	{ N_MSG_TTL_MENU_RESURRECTION,
		"ïޤ?" },
	{ N_MSG_MENU_RESURRECTION_ERR_ALL_MBR,
		"ïǤޤ" },
	{ N_MSG_MENU_RESURRECTION,
		"%s ֤ä" },
	{ N_MSG_MENU_RESURRECTION_FAILURE,
		"%s ֤ʤä" },
	{ N_MSG_MENU_RESURRECTION_ERR,
		"%s ϻǤޤ" },
	{ N_MSG_MENU_CONTRIBUTION,
		"%s  %ld " STR_GOLD " դ" },

	{ N_MSG_MENU_BAR_FORM,
		"ѡƥ" },

	{ N_MSG_MENU_BAR_EDIT_MBR,
		"СԽ" },
	{ N_MSG_MENU_BAR_NEW_MBR,
		"СϿ" },
	{ N_MSG_MENU_BAR_REMOVE_MBR,
		"С" },

	{ N_MSG_MENU_BAR_EDIT_CLASS,
		"饹Խ" },
	{ N_MSG_MENU_BAR_NEW_CLASS,
		"饹Ͽ" },
	{ N_MSG_MENU_BAR_REMOVE_CLASS,
		"饹" },

	{ N_MSG_MENU_BAR_SAVE,
		"" },

	{ N_MSG_TTL_MENU_BAR_FORM,
		"ѡƥ" },
	{ N_MSG_MENU_BAR_JOIN,
		"ѡƥ˲ä" },
	{ N_MSG_MENU_BAR_NOT_JOIN,
		"ѡƥ鳰" },

	{ N_MSG_TTL_MENU_BAR_EDIT_MBR,
		"СԽ" },
	{ N_MSG_TTL_MENU_BAR_EDIT_MBR_SUB,
		"%s 򥨥ǥå" },
	{ N_MSG_MENU_BAR_ARRANGE,
		"Ƭ¤ٴ" },
	{ N_MSG_TTL_MENU_BAR_REMOVE_MBR,
		"С" },

	{ N_MSG_TTL_MENU_ASK_EDIT_MBR,
		"ѹ¸ޤ?" },
	{ N_MSG_TTL_MENU_ASK_NEW_MBR,
		"ǥСϿޤ?" },
	{ N_MSG_TTL_MENU_ASK_REMOVE_MBR,
		"˥Сޤ?" },

	{ N_MSG_MENU_REMOVE_MBR_NAME,
		"%s ޤ" },
	{ N_MSG_MENU_REMOVE_MBR_LEV,
		"ǹ٥ %ld Ǥ" },
	{ N_MSG_MENU_REMOVE_MBR_GOLD,
		"%ld " STR_GOLD " Ƥޤ" },

	{ N_MSG_TTL_MENU_ASK_EDIT_CLASS,
		"ѹ¸ޤ?" },
	{ N_MSG_TTL_MENU_ASK_NEW_CLASS,
		"ǥ饹Ͽޤ?" },
	{ N_MSG_TTL_MENU_ASK_REMOVE_CLASS,
		"˥饹ޤ?" },

	{ N_MSG_MENU_NEW_MBR,
		"New Character" },
	{ N_MSG_MENU_NEW_CLASS,
		"New Class" },

	{ N_MSG_MENU_INN_STAY,
		"ޤ %8ld " STR_GOLD },
	{ N_MSG_MENU_INN_DO_STAY,
		"񤷤īˤʤä" },

/* menu town end */

/* menu spell begin */

	{ N_MSG_SPELL_EXTENT_NORMAL,
		"̾" },
	{ N_MSG_SPELL_EXTENT_SPREAD,
		"Ȼ" },
	{ N_MSG_SPELL_EXTENT_MASS,
		"" },
	{ N_MSG_SPELL_EXTENT_HALF,
		"Ⱦ" },

/* menu spell end */

/* menu end */

	{ N_MSG_MBR_DATA_SEL,
		"*%s*" },
	{ N_MSG_MBR_DATA_NOT_SEL,
		" %s " },

	{ N_MSG_GETS_MBR_NAME,
		"̾ϤƲ(%ld ʸ)" },
	{ N_MSG_GETS_MBR_FACE,
		"ʸʸϤƲ" },
	{ N_MSG_GETS_RACE_NAME,
		"²̾ϤƲ(%ld ʸ)" },

	{ N_MSG_RACE_STR_PUREBRED,
		"%sν" },
	{ N_MSG_RACE_STR_MIXED,
		"%s & %s" },

	{ N_MSG_MBR_DATA_NAME_TTL,
		"̾  : " },
	{ N_MSG_MBR_DATA_FACE_TTL,
		"    : " },
	{ N_MSG_MBR_DATA_RACE_STR_TTL,
		"²  : " },
	{ N_MSG_MBR_DATA_RACE_NAME_TTL,
		"²̾: " },
	{ N_MSG_MBR_DATA_SEX_TTL,
		"  : " },

	{ N_MSG_MBR_DATA_HP_VAL,
		"HP: " },
	{ N_MSG_MBR_DATA_MP_VAL,
		"MP: " },

	{ N_MSG_MBR_DATA_VAL_TTL,
		"                     ()" },
	{ N_MSG_MBR_DATA_HIT_TTL,
		"            : " },
	{ N_MSG_MBR_DATA_HIT,
		"%s%4ld (%4ld)" },
	{ N_MSG_MBR_DATA_WPN_CRTCL_TTL,
		"ƥ빶: " },
	{ N_MSG_MBR_DATA_WPN_CRTCL,
		"%s%4ld (%4ld)" },
	{ N_MSG_MBR_DATA_DAM_TTL,
		"᡼          : " },
	{ N_MSG_MBR_DATA_DAM,
		"%s%4ld (%4ld)" },
	{ N_MSG_MBR_DATA_DEF_TTL,
		"ɸ            : " },
	{ N_MSG_MBR_DATA_DEF,
		"%s%4ld" },
	{ N_MSG_MBR_DATA_ARMOR_CRTCL_TTL,
		"ƥɸ: " },
	{ N_MSG_MBR_DATA_ARMOR_CRTCL,
		"%s%4ld" },
	{ N_MSG_MBR_DATA_AC_TTL,
		"ޡ饹    : " },
	{ N_MSG_MBR_DATA_AC,
		"%s%4ld" },

	{ N_MSG_MBR_DATA_GOLD_TTL,
		STR_GOLD ": " },
	{ N_MSG_CALENDAR,
		"%ldǯ%ld%ld%ld%ldʬ" },

	{ N_MSG_MBR_DATA_STAT_TTL,
		":" },
	{ N_MSG_MBR_DATA_STAT_NULL,
		"[    ]" },
	{ N_MSG_MBR_DATA_STAT_DEAD,
		"[˴]" },
	{ N_MSG_MBR_DATA_STAT_STONE,
		"[в]" },
	{ N_MSG_MBR_DATA_STAT_PARALYZE,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_POISON,
		"[  ]" },
	{ N_MSG_MBR_DATA_STAT_CONFUSION,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_BLIND,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_SLEEP,
		"[̲]" },
	{ N_MSG_MBR_DATA_STAT_SILENCE,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_FEAR,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_HALLUCINATION,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_CHARM,
		"[̥λ]" },
	{ N_MSG_MBR_DATA_STAT_FLY,
		"[ͷ]" },
	{ N_MSG_MBR_DATA_STAT_HUNGRY,
		"[ʢ]" },
	{ N_MSG_MBR_DATA_STAT_STARVATION,
		"[]" },
	{ N_MSG_MBR_DATA_STAT_FAINT,
		"[ޤ]" },
	{ N_MSG_MBR_DATA_STAT_DRUNK,
		"[줤]" },

	{ N_MSG_MBR_DATA_LEV_TTL,
		"٥" },
	{ N_MSG_MBR_DATA_EXP_TTL,
		"и" },
	{ N_MSG_MBR_DATA_NEED_EXP_TTL,
		"ɬ׷и" },

	{ N_MSG_FMT_MBR_DATA_ABL,
		"%5s%s%2ld %-3s %10ld/%10ld%s" },
	{ N_MSG_FMT_MBR_DATA_VALUE,
		"%4ld" },
	{ N_MSG_FMT_MBR_DATA_ADD_LEV,
		"%+2ld" },
	{ N_MSG_MBR_DATA_HP_TTL,
		"HP : " },
	{ N_MSG_MBR_DATA_MP_TTL,
		"MP : " },
	{ N_MSG_MBR_DATA_DEX_TTL,
		"DEX: " },
	{ N_MSG_MBR_DATA_STR_TTL,
		"STR: " },
	{ N_MSG_MBR_DATA_AGI_TTL,
		"AGI: " },
	{ N_MSG_MBR_DATA_WIS_TTL,
		"WIS: " },
	{ N_MSG_MBR_DATA_INT_TTL,
		"INT: " },
	{ N_MSG_MBR_DATA_CHA_TTL,
		"CHA: " },
	{ N_MSG_MBR_DATA_FIG_TTL,
		"FIG: " },
	{ N_MSG_MBR_DATA_MON_TTL,
		"MON: " },
	{ N_MSG_MBR_DATA_HUN_TTL,
		"HUN: " },
	{ N_MSG_MBR_DATA_THI_TTL,
		"THI: " },
	{ N_MSG_MBR_DATA_MAG_TTL,
		"MAG: " },
	{ N_MSG_MBR_DATA_SOR_TTL,
		"SOR: " },
	{ N_MSG_MBR_DATA_ENC_TTL,
		"ENC: " },
	{ N_MSG_MBR_DATA_SUM_TTL,
		"SUM: " },
	{ N_MSG_MBR_DATA_PRI_TTL,
		"PRI: " },
	{ N_MSG_MBR_DATA_SHA_TTL,
		"SHA: " },
	{ N_MSG_MBR_DATA_BAR_TTL,
		"BAR: " },
	{ N_MSG_MBR_DATA_NIN_TTL,
		"NIN: " },

	{ N_MSG_FMT_MBR_DATA_RESI,
		"%s%3ld%" },
	{ N_MSG_MBR_DATA_RESI_TTL,
		"---- " },
	{ N_MSG_MBR_DATA_RESI_KNOC_TTL,
		": " },
	{ N_MSG_MBR_DATA_RESI_SLAS_TTL,
		"·: " },
	{ N_MSG_MBR_DATA_RESI_STIN_TTL,
		": " },
	{ N_MSG_MBR_DATA_RESI_HEAT_TTL,
		"Ǯ: " },
	{ N_MSG_MBR_DATA_RESI_COLD_TTL,
		": " },
	{ N_MSG_MBR_DATA_RESI_WIND_TTL,
		": " },
	{ N_MSG_MBR_DATA_RESI_ACID_TTL,
		"ڻ: " },
	{ N_MSG_MBR_DATA_RESI_ELEC_TTL,
		": " },
	{ N_MSG_MBR_DATA_RESI_POIS_TTL,
		": " },

	{ N_MSG_MBR_DATA_CLASS_TTL,
		"饹: " },
	{ N_MSG_MBR_DATA_CLASS,
		"%s%s" },

	{ N_MSG_MBR_DATA_NEXT_PAGE,
		"Υڡ" },

	{ N_MSG_LEV_UP_LEFT_OFF,
		" " },
	{ N_MSG_LEV_UP_RIGHT_OFF,
		" " },
	{ N_MSG_LEV_UP_LEFT_ON,
		"*" },
	{ N_MSG_LEV_UP_RIGHT_ON,
		"*" },

/* edit class begin */

	{ N_MSG_EDIT_CLASS_TTL,
		"%s%3ld%%" },
	{ N_MSG_EDIT_CLASS_ADD_SEL,
		"<+>" },
	{ N_MSG_EDIT_CLASS_ADD_NOT_SEL,
		" + " },
	{ N_MSG_EDIT_CLASS_SUB_SEL,
		"<->" },
	{ N_MSG_EDIT_CLASS_SUB_NOT_SEL,
		" - " },
	{ N_MSG_EDIT_CLASS_TOTAL,
		"TOTAL: %3ld" },
	{ N_MSG_EDIT_CLASS_NAME,
		"%s%-*s" },
	{ N_MSG_EDIT_CLASS_PREV,
		"Υ饹" },
	{ N_MSG_EDIT_CLASS_NEXT,
		"Υ饹" },

/* edit class end */

	{ N_MSG_FMT_MSG,
		"%-*s" },
	{ N_MSG_FMT_WPN_IDENTIFIED,
		"%2ld %s(%+ld,%+ld,%+ld)" },
	{ N_MSG_FMT_WPN_SLAYER,
		"%2ld %s %c 쥤䡼"
		"(%+ld,%+ld,%+ld)" },
	{ N_MSG_FMT_WPN_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_ARMOR_IDENTIFIED,
		"%2ld %s[%+ld,%+ld,%+ld]" },
	{ N_MSG_FMT_ARMOR_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_POTION_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_POTION_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_SCROLL_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_SCROLL_NOT_IDENTIFIED,
		"%2ld %sδʪ" },
	{ N_MSG_FMT_WAND_IDENTIFIED,
		"%2ld %sΥ(%ld)" },
	{ N_MSG_FMT_ROD_IDENTIFIED,
		"%2ld %sΥå(%ld)" },
	{ N_MSG_FMT_STAFF_IDENTIFIED,
		"%2ld %sΥå(%ld)" },
	{ N_MSG_FMT_WAND_NOT_IDENTIFIED,
		"%2ld %sΥ" },
	{ N_MSG_FMT_ROD_NOT_IDENTIFIED,
		"%2ld %sΥå" },
	{ N_MSG_FMT_STAFF_NOT_IDENTIFIED,
		"%2ld %sΥå" },
	{ N_MSG_FMT_ACCE_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_RING_NOT_IDENTIFIED,
		"%2ld %sλ" },
	{ N_MSG_FMT_AMULET_NOT_IDENTIFIED,
		"%2ld %sθ" },
	{ N_MSG_FMT_NECKLACE_NOT_IDENTIFIED,
		"%2ld %sμ" },
	{ N_MSG_FMT_LIGHT_IDENTIFIED,
		"%2ld %s %ld" },
	{ N_MSG_FMT_LIGHT_NOT_IDENTIFIED,
		"%2ld %s %ld" },
	{ N_MSG_FMT_SPIKE_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_SPIKE_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_FOOD_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_FOOD_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_CHEST_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_CHEST_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_TOBACCO_IDENTIFIED,
		"%2ld %s(%s: %ld)" },
	{ N_MSG_FMT_TOBACCO_NOT_IDENTIFIED,
		"%2ld %s(%s)" },
	{ N_MSG_FMT_TOBACCO_STUB_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_PIPE_IDENTIFIED,
		"%2ld %s(%ld)" },
	{ N_MSG_FMT_PIPE_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_PIPE_STUB_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_COIN_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_COIN_NOT_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_JUNK_IDENTIFIED,
		"%2ld %s" },
	{ N_MSG_FMT_JUNK_NOT_IDENTIFIED,
		"%2ld %s" },

	{ N_MSG_FMT_ART_NAME,
		"%-*s %8ld " STR_GOLD },
	{ N_MSG_FMT_IDENTIFY_ITEM,
		" %s " },
	{ N_MSG_FMT_MARK_MNSTR,
		"%s  %s ޡ" },
	{ N_MSG_FMT_ART_NAME_EQUIP,
		"%s%s:%s" },

	{ N_MSG_ERR_DOOR_OPEN_JAMMED,
		"ɥꤵƤƳޤ" },
	{ N_MSG_ERR_DOOR_CLOSE_JAMMED,
		"ɥꤵƤĤޤ" },
	{ N_MSG_ERR_DOOR_CLOSE_BROKEN,
		"ɥƤĤޤ" },
	{ N_MSG_ERR_DOOR_JAM_SPIKE,
		"%s äƤޤ" },
	{ N_MSG_ERR_DOOR_JAM_BROKEN,
		"ɥƤƸޤ" },
	{ N_MSG_ERR_DOOR_JAM_JAMMED,
		"ɥϸꤵƤޤ" },
	{ N_MSG_ERR_DOOR_DISARM_NOT_JAM,
		"ɥϸꤵƤޤ" },
	{ N_MSG_ERR_DOOR_DISARM_BROKEN,
		"ɥϲƤޤ" },
	{ N_MSG_ERR_DOOR_DISARM_LEV,
		"ɥ" STR_DISARM "˼Ԥ" },
	{ N_MSG_ERR_DOOR_BREAK_SHOP,
		"ʤȤ򤷤ܤޤ" },
	{ N_MSG_ERR_DOOR_BREAK_BROKEN,
		"ɥϴ˲Ƥޤ" },
	{ N_MSG_ERR_DOOR_BREAK_LEV,
		"ɥޤǤ" },

	{ N_MSG_ERR_TRAP_DISARM_LEV,
		"櫤" STR_DISARM "˼Ԥ" },
	{ N_MSG_ERR_TRAP_BREAK_LEV,
		"櫤ޤǤ" },

	{ N_MSG_ERR_ITEM_DISARM_LEV,
		"ƥ" STR_DISARM "˼Ԥ" },

	{ N_MSG_ERR_STAIRS,
		"Сʤ¦ˤޤ" },
	{ N_MSG_ERR_STAIRS_UP,
		"С곬ʤ¦ˤޤ" },
	{ N_MSG_ERR_STAIRS_DOWN,
		"С곬ʤ¦ˤޤ" },

	{ N_MSG_ERR_EQUIP_SEL_ITEM,
		"륢ƥबĤޤǤ" },

	{ N_MSG_ERR_CHK_KEY,
		"[%c: 0x%04x]̵ʥǤ" },

	{ N_MSG_ERR_MENU_SEL_ITEM,
		"%s κξ֤Ǥޤ" },
	{ N_MSG_ERR_MENU_SEL_EQUIP,
		"%s κξ֤Ǥޤ" },
	{ N_MSG_ERR_MENU_MARK_BLIND,
		"%s ܤʤΤǥޡޤ" },
	{ N_MSG_ERR_MENU_BAR_SEL_MBR,
		"ѡƥ˥СäƲ" },
	{ N_MSG_ERR_MENU_WANTING,
		"%s  %ld " STR_GOLD "­ޤ" },
	{ N_MSG_ERR_MENU_DATA_LEV_UP,
		"%s Ϸиͤ­ޤ" },

	{ N_MSG_ERR_MENU_EDIT_CLASS,
		"פ 100% ˤƲ" },
	{ N_MSG_ERR_MENU_NEW_CLASS,
		"ʾ奯饹ޤ" },
	{ N_MSG_ERR_REMOVE_CLASS,
		"ʾ奯饹Ǥޤ" },

	{ N_MSG_ERR_MENU_PAGE_OVER,
		"˥塼Υڡ¿ޤ" },
	{ N_MSG_ERR_MENU_SRCH_PATH,
		"˥塼θԤޤ'%s'" },
	{ N_MSG_ERR_ACCEL_KEY,
		"졼ʣƤޤ '%c':'%s'" },

	{ N_MSG_ERR_FILL_LAMP,
		"Ƥޤ" },
	{ N_MSG_ERR_FILL_LAMP_NON_OIL,
		"ʳ뤷" },
	{ N_MSG_ERR_THROW,
		"%s ꤲʪ̵ʤޤ" },
	{ N_MSG_ERR_MNSTR_NULL,
		"ˤϥ󥹥Ϥޤ" },
	{ N_MSG_ERR_NOT_FIND,
		"%s  %s ޤ" },
	{ N_MSG_ERR_ITEM_CURSE,
		"%s ϼƤƳޤ" },
	{ N_MSG_ERR_ITEM_FULL,
		"%s ϻʪäѤǤ" },
	{ N_MSG_ERR_ITEM_FLY,
		"%s ⤫ǤΤ %s 򽦤ޤ" },
	{ N_MSG_ERR_GIVE_MBR_ITEM,
		"%s ϻʪäѤ %s Ƥޤ" },
	{ N_MSG_ERR_GIVE_MBR_CHEST,
		"%s Ϥʾ %s ŤƻƤޤ" },
	{ N_MSG_ERR_ITEM_BREAK_BROKEN,
		"%s ϴ˲Ƥޤ" },
	{ N_MSG_ERR_ITEM_BREAK_LEV,
		"%s ޤǤ" },
	{ N_MSG_ERR_EQUIP_TWO_HANDED_WPN,
		"%s ξȽƱޤ" },

	{ N_MSG_ERR_POTION_COLOR,
		"ο̾ǡ۾Ǥ\n" },
	{ N_MSG_ERR_STICK_MATERIAL,
		"κ̾ǡ۾Ǥ\n" },
	{ N_MSG_ERR_RING_MATERIAL,
		"ؤκ̾ǡ۾Ǥ\n" },
	{ N_MSG_ERR_AMULET_MATERIAL,
		"κ̾ǡ۾Ǥ\n" },
	{ N_MSG_ERR_WPN_RATE_TAB,
		"ǡ۾Ǥ\n" },
	{ N_MSG_ERR_SET_TTY,
		"ü꤬ޤǤ\n" },
	{ N_MSG_ERR_HOME_DIR,
		"ۡࡦǥ쥯ȥ [%s] ꤬"
		"ޤǤ\n" },
	{ N_MSG_ERR_GAME_DIR_SAVE,
		"'%s'˽񤭹ޤǤ" },

	{ N_MSG_ERR_TOWN_MAP,
		"ޥåסǡ۾Ǥ\n" },
	{ N_MSG_ERR_TOWN_MAP_X_SIZE,
		"ޥåסǡοʿ㤤ޤ %ld/%ld" },
	{ N_MSG_ERR_TOWN_MAP_Y_SIZE,
		"ޥåסǡοľ㤤ޤ %ld/%ld" },
	{ N_MSG_ERR_TOWN_MAP_STR_LEN,
		"ޥåסǡοɽʸĹ"
		"12ʸˤƲ %ld" },
	{ N_MSG_ERR_TOWN_MAP_SHOP,
		"ޥåסǡäƤʤåפޤ\n" },

	/* Data Load */

	{ N_MSG_ERR_LOAD_WQUOTE,
		"'\"' ͭޤ" },
	{ N_MSG_ERR_LOAD_LINE_LEN,
		"Ԥʸ礤ޤ %ld/%ld" },
	{ N_MSG_ERR_LOAD_EOF,
		"ե뤬ڤƤޤ" },
	{ N_MSG_ERR_LOAD_TOWN_PTN,
		"Ťޥåסǡ '%s' Хååפޤ" },

	/* Data Save */

	{ N_MSG_ERR_SAVE_TOWN_PTN,
		"ޥåסǡֽޤǤ" },
	{ N_MSG_ERR_SAVE_CRSR_PTN,
		"롦ѥ󤬥ֽޤǤ" },

	{ N_MSG_WRN_RENAME,
		"ե̾ѹޤ\n\t'%s' ->\n\t'%s'" },
	{ N_MSG_WRN_CHK_ID,
		"ID:\n'%s'\n'%s'" },

	{ N_MSG_FMT_COPYRIGHT,
		STR_FMT_COPYRIGHT },
	{ N_MSG_ABOUT_GAME,
		"ܥץϥե꡼եȥǤ\n"
		"ʤϡ Free Software Foundation ɽ"
		" GNU ̸ͭѵΡ֥С󣲡"
		"ϤʹߤγƥС椫餤줫򤷡"
		"ΥС˽äܥץ"
		"ۤޤѹ뤳ȤǤޤ\n"
		"\n"
		"ܥץͭѤȤϻפޤۤˤäƤϡ"
		"ԾڤŪŬˤĤƤΰۤݾڤޤ,"
		"ʤݾڤԤʤޤ\n"
		"ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ\n"
		"\n"
		"ʤϡܥץȰ GNU ̸ͭѵ"
		"μ̤äƤϤǤǤʤϡ\n"
		"  Free Software Foundation, Inc.,\n"
		"  59 Temple Place, Suite 330, Boston, MA 02111-1307, USA\n"
		"ؼ񤤤Ƥ\n"
	},

#undef	STR_SQUARE

#undef	STR_EQUIP_WIELDING
#undef	STR_EQUIP_SHIELD
#undef	STR_EQUIP_BOW
#undef	STR_EQUIP_ARW
#undef	STR_EQUIP_HEAD
#undef	STR_EQUIP_NECK
#undef	STR_EQUIP_BODY
#undef	STR_EQUIP_ARM
#undef	STR_EQUIP_RIGHT_HAND
#undef	STR_EQUIP_LEFT_HAND
#undef	STR_EQUIP_FEET
#undef	STR_EQUIP_ABOUT_BODY
#undef	STR_EQUIP_LIGHT_SOURCE

#undef	STR_DISARM
#undef	STR_GOLD

#undef	STR_FIG
#undef	STR_MON
#undef	STR_HUN
#undef	STR_THI

#undef	STR_MAG
#undef	STR_SOR
#undef	STR_ENC
#undef	STR_SUM
#undef	STR_PRI
#undef	STR_SHA
#undef	STR_BAR
#undef	STR_NIN
